@@ -16,6 +16,8 @@ class Flags(enum.IntFlag):
     ASM_CUSTOM_RULES = 1 << 8
     ASM_CUSTOM_BLOCKING_RESPONSE = 1 << 9
     ASM_TRUSTED_IPS = 1 << 10
+    ASM_PROCESSOR_OVERRIDES = 1 << 16
+    ASM_CUSTOM_DATA_SCANNERS = 1 << 17
     ASM_EXCLUSION_DATA = 1 << 18
     ASM_RASP_SQLI = 1 << 21
     ASM_RASP_LFI = 1 << 22
@@ -44,6 +46,8 @@ _ALL_ASM_BLOCKING = (
     | Flags.ASM_USER_BLOCKING
     | Flags.ASM_CUSTOM_RULES
     | Flags.ASM_CUSTOM_BLOCKING_RESPONSE
+    | Flags.ASM_PROCESSOR_OVERRIDES
+    | Flags.ASM_CUSTOM_DATA_SCANNERS
     | Flags.ASM_EXCLUSION_DATA
     | Flags.ASM_ENDPOINT_FINGERPRINT
     | Flags.ASM_SESSION_FINGERPRINT
