@@ -42,7 +42,7 @@ def report_stack(
 
     if span is None or stack_id is None:
         return False
-    appsec_traces = span.get_struct_tag(STACK_TRACE.TAG) or {}
+    appsec_traces = span._get_struct_tag(STACK_TRACE.TAG) or {}
     current_list = appsec_traces.get(namespace, [])
     total_length = len(current_list)
 
@@ -80,5 +80,5 @@ def report_stack(
     res["frames"] = frames
     current_list.append(res)
     appsec_traces[namespace] = current_list
-    span.set_struct_tag(STACK_TRACE.TAG, appsec_traces)
+    span._set_struct_tag(STACK_TRACE.TAG, appsec_traces)
     return True
