@@ -1,9 +1,7 @@
 #include "helpers.h"
-#include "initializer/initializer.h"
 #include "utils/python_error_guard.h"
-
 #include <algorithm>
-#include <iostream>
+#include <cstdio>
 
 using namespace pybind11::literals;
 namespace py = pybind11;
@@ -25,7 +23,8 @@ api_common_replace(const py::str& string_method,
 {
     const StrType res = py::getattr(candidate_text, string_method)(*args, **kwargs);
 
-    const auto tx_map = Initializer::get_tainting_map();
+    const auto tx_map = taint_engine_context->get_tainted_object_map(candidate_text.ptr());
+
     if (not tx_map or tx_map->empty()) {
         return res;
     }
@@ -45,10 +44,6 @@ as_formatted_evidence(const string& text,
                       const optional<TagMappingMode>& tag_mapping_mode,
                       const optional<const py::dict>& new_ranges)
 {
-    if (const auto tx_map = Initializer::get_tainting_map(); !tx_map) {
-        return text;
-    }
-
     if (text_ranges.empty() or text.empty()) {
         return text;
     }
@@ -107,13 +102,18 @@ api_as_formatted_evidence(const StrType& text,
                           const optional<TagMappingMode>& tag_mapping_mode,
                           const optional<const py::dict>& new_ranges)
 {
-    if (const auto tx_map = Initializer::get_tainting_map(); !tx_map) {
+    const auto tx_map = taint_engine_context->get_tainted_object_map(text.ptr());
+    if (!tx_map or tx_map->empty()) {
         return text;
     }
 
     TaintRangeRefs _ranges;
     if (!text_ranges or !text_ranges.has_value()) {
-        _ranges = api_get_ranges(text);
+        auto [ranges, ranges_error] = get_ranges(text.ptr(), tx_map);
+        if (ranges_error) {
+            return text;
+        }
+        _ranges = std::move(ranges);
     } else {
         // text_ranges.value throws a compile error: 'value' is unavailable: introduced in macOS 10.13
         _ranges = *text_ranges;
@@ -125,13 +125,17 @@ py::bytearray
 api_convert_escaped_text_to_taint_text(const py::bytearray& taint_escaped_text, const TaintRangeRefs& ranges_orig)
 {
 
-    const auto tx_map = Initializer::get_tainting_map();
-
+    const auto tx_map = taint_engine_context->get_tainted_object_map(taint_escaped_text.ptr());
+    if (!tx_map) {
+        return taint_escaped_text;
+    }
     const py::bytes bytes_text = py::bytes() + taint_escaped_text;
 
     const std::tuple result = convert_escaped_text_to_taint_text<py::bytes>(bytes_text, ranges_orig);
     PyObject* new_result = new_pyobject_id((py::bytearray() + get<0>(result)).ptr());
+
     set_ranges(new_result, get<1>(result), tx_map);
+
     return py::reinterpret_steal<py::bytearray>(new_result);
 }
 
@@ -139,10 +143,13 @@ template<class StrType>
 StrType
 api_convert_escaped_text_to_taint_text(const StrType& taint_escaped_text, const TaintRangeRefs& ranges_orig)
 {
-    const auto tx_map = Initializer::get_tainting_map();
-
+    const auto tx_map = taint_engine_context->get_tainted_object_map_from_ranges(ranges_orig);
+    if (!tx_map) {
+        return taint_escaped_text;
+    }
     auto [result_text, result_ranges] = convert_escaped_text_to_taint_text<StrType>(taint_escaped_text, ranges_orig);
     PyObject* new_result = new_pyobject_id(result_text.ptr());
+
     set_ranges(new_result, result_ranges, tx_map);
     return py::reinterpret_steal<StrType>(new_result);
 }
@@ -351,14 +358,16 @@ set_ranges_on_splitted(const py::object& source_str,
     return some_set;
 }
 
+// TODO: we can remove api_set_ranges_on_splitted because it is not used, in tests only
 template<class StrType>
 bool
 api_set_ranges_on_splitted(const StrType& source_str,
                            const TaintRangeRefs& source_ranges,
                            const py::list& split_result,
-                           bool include_separator)
+                           bool include_separator,
+                           size_t context_id)
 {
-    const auto tx_map = Initializer::get_tainting_map();
+    const auto tx_map = taint_engine_context->get_tainted_object_map_by_ctx_id(context_id);
     if (not tx_map or tx_map->empty()) {
         return false;
     }
@@ -383,15 +392,55 @@ has_pyerr_as_string()
     return error_guard.error_as_stdstring();
 }
 
-py::str
-has_pyerr_as_pystr()
+// Returns a tuple with (all ranges, ranges of candidate_text)
+// FIXME: Take a PyList as parameter_list instead of a py::tuple (same for the
+// result)
+tuple<TaintRangeRefs, TaintRangeRefs>
+are_all_text_all_ranges(PyObject* candidate_text,
+                        const py::tuple& parameter_list,
+                        const TaintedObjectMapTypePtr& tx_map)
 {
-    PythonErrorGuard error_guard;
-    if (not error_guard.has_error()) {
+    if (not is_tainteable(candidate_text)) {
         return {};
     }
 
-    return error_guard.error_as_pystr();
+    TaintRangeRefs all_ranges;
+
+    auto [candidate_text_ranges, ranges_error] = get_ranges(candidate_text, tx_map);
+    if (not ranges_error) {
+        for (const auto& param_handler : parameter_list) {
+            if (const auto param = param_handler.cast<py::object>().ptr(); is_tainteable(param)) {
+                if (auto [ranges, ranges_error] = get_ranges(param, tx_map); not ranges_error) {
+                    all_ranges.insert(all_ranges.end(), ranges.begin(), ranges.end());
+                }
+            }
+        }
+        all_ranges.insert(all_ranges.end(), candidate_text_ranges.begin(), candidate_text_ranges.end());
+    }
+    return { all_ranges, candidate_text_ranges };
+}
+
+tuple<TaintRangeRefs, TaintRangeRefs>
+api_are_all_text_all_ranges(py::handle& candidate_text, const py::list& parameter_list)
+{
+    const auto tx_map = taint_engine_context->get_tainted_object_map_from_list_of_pyobjects(
+      { candidate_text.ptr(), parameter_list.ptr() });
+    if (not tx_map or tx_map->empty()) {
+        return { {}, {} };
+    }
+    const py::tuple params_tuple = py::tuple(parameter_list);
+    return are_all_text_all_ranges(candidate_text.ptr(), params_tuple, tx_map);
+}
+
+tuple<TaintRangeRefs, TaintRangeRefs>
+api_are_all_text_all_ranges(py::handle& candidate_text, const py::tuple& parameter_list)
+{
+    const auto tx_map = taint_engine_context->get_tainted_object_map_from_list_of_pyobjects(
+      { candidate_text.ptr(), parameter_list.ptr() });
+    if (not tx_map or tx_map->empty()) {
+        return { {}, {} };
+    }
+    return are_all_text_all_ranges(candidate_text.ptr(), parameter_list, tx_map);
 }
 
 void
@@ -417,22 +466,22 @@ pyexport_aspect_helpers(py::module& m)
           "source_str"_a,
           "source_ranges"_a,
           "split_result"_a,
-          // cppcheck-suppress assignBoolToPointer
-          "include_separator"_a = false);
+          "include_separator"_a,
+          "context_id"_a);
     m.def("set_ranges_on_splitted",
           &api_set_ranges_on_splitted<py::str>,
           "source_str"_a,
           "source_ranges"_a,
           "split_result"_a,
-          // cppcheck-suppress assignBoolToPointer
-          "include_separator"_a = false);
+          "include_separator"_a,
+          "context_id"_a);
     m.def("set_ranges_on_splitted",
           &api_set_ranges_on_splitted<py::bytearray>,
           "source_str"_a,
           "source_ranges"_a,
           "split_result"_a,
-          // cppcheck-suppress assignBoolToPointer
-          "include_separator"_a = false);
+          "include_separator"_a,
+          "context_id"_a);
     m.def("as_formatted_evidence",
           &api_as_formatted_evidence<py::bytes>,
           "text"_a,
@@ -454,6 +503,18 @@ pyexport_aspect_helpers(py::module& m)
           "tag_mapping_function"_a = nullopt,
           "new_ranges"_a = nullopt,
           py::return_value_policy::move);
+    m.def("are_all_text_all_ranges",
+          static_cast<tuple<TaintRangeRefs, TaintRangeRefs> (*)(py::handle&, const py::list&)>(
+            &api_are_all_text_all_ranges),
+          "candidate_text"_a,
+          "parameter_list"_a,
+          py::return_value_policy::move);
+    m.def("are_all_text_all_ranges",
+          static_cast<tuple<TaintRangeRefs, TaintRangeRefs> (*)(py::handle&, const py::tuple&)>(
+            &api_are_all_text_all_ranges),
+          "candidate_text"_a,
+          "parameter_list"_a,
+          py::return_value_policy::move);
     m.def("_convert_escaped_text_to_tainted_text",
           &api_convert_escaped_text_to_taint_text<py::bytes>,
           "taint_escaped_text"_a,
