@@ -1,11 +1,20 @@
 #pragma once
 
-#include "initializer/initializer.h"
-#include "taint_tracking/taint_range.h"
 #include <iostream>
 #include <pybind11/pybind11.h>
 #include <pybind11/stl.h>
 #include <regex>
+#include <sstream>
+#include <unordered_map>
+#include <utility>
+
+#include "constants.h"
+#include "context/taint_engine_context.h"
+#include "initializer/initializer.h"
+#include "structmember.h"
+#include "taint_tracking/source.h"
+#include "taint_tracking/taint_range.h"
+#include "utils/string_utils.h"
 
 using namespace pybind11::literals;
 namespace py = pybind11;
@@ -18,24 +27,31 @@ StrType
 api_common_replace(const py::str& string_method,
                    const StrType& candidate_text,
                    const py::args& args,
-                   const py::kwargs& kwargs);
+                   const py::kwargs& kwargs
+
+);
 
 template<class StrType>
 StrType
-all_as_formatted_evidence(const StrType& text, TagMappingMode tag_mapping_mode)
+all_as_formatted_evidence(const StrType& text, TagMappingMode tag_mapping_mode, const TaintedObjectMapTypePtr& tx_map)
 {
-    if (const auto tx_map = Initializer::get_tainting_map(); !tx_map) {
+    auto [ranges, ranges_error] = get_ranges(text.ptr(), tx_map);
+    if (ranges_error) {
         return text;
     }
-    TaintRangeRefs text_ranges = api_get_ranges(text);
-    return StrType(as_formatted_evidence(AnyTextObjectToString(text), text_ranges, tag_mapping_mode, nullopt));
+    return StrType(as_formatted_evidence(AnyTextObjectToString(text), ranges, tag_mapping_mode, nullopt));
 }
 
+tuple<TaintRangeRefs, TaintRangeRefs>
+are_all_text_all_ranges(PyObject* candidate_text,
+                        const py::tuple& parameter_list,
+                        const TaintedObjectMapTypePtr& tx_map);
+
 template<class StrType>
 StrType
 int_as_formatted_evidence(const StrType& text, TaintRangeRefs& text_ranges, TagMappingMode tag_mapping_mode)
 {
-    if (const auto tx_map = Initializer::get_tainting_map(); !tx_map) {
+    if (const auto tx_map = taint_engine_context->get_tainted_object_map(text.ptr()); !tx_map) {
         return text;
     }
     return StrType(as_formatted_evidence(AnyTextObjectToString(text), text_ranges, tag_mapping_mode, nullopt));
@@ -77,7 +93,8 @@ bool
 api_set_ranges_on_splitted(const StrType& source_str,
                            const TaintRangeRefs& source_ranges,
                            const py::list& split_result,
-                           bool include_separator = false);
+                           bool include_separator,
+                           size_t context_id);
 
 PyObject*
 api_convert_escaped_text_to_taint_text(PyObject* taint_escaped_text,
@@ -89,9 +106,6 @@ has_pyerr();
 std::string
 has_pyerr_as_string();
 
-py::str
-has_pyerr_as_pystr();
-
 struct EVIDENCE_MARKS
 {
     static constexpr const char* BLANK = "";
