@@ -18,7 +18,6 @@
 #include "aspects/aspects_exports.h"
 #include "constants.h"
 #include "context/_taint_engine_context.h"
-#include "initializer/_initializer.h"
 #include "taint_tracking/taint_tracking.h"
 #include "tainted_ops/tainted_ops.h"
 #include "utils/generic_utils.h"
@@ -51,7 +50,6 @@ static struct PyModuleDef aspects __attribute__((used)) = { PyModuleDef_HEAD_INI
 
 static PyMethodDef OpsMethods[] = {
     { "new_pyobject_id", (PyCFunction)api_new_pyobject_id, METH_FASTCALL, "new pyobject id" },
-    { "set_ranges_from_values", ((PyCFunction)api_set_ranges_from_values), METH_FASTCALL, "set_ranges_from_values" },
     { "taint_pyobject", ((PyCFunction)api_taint_pyobject), METH_FASTCALL, "api_taint_pyobject" },
     { nullptr, nullptr, 0, nullptr }
 };
@@ -74,7 +72,25 @@ PYBIND11_MODULE(_native, m)
     // Create a atexit callback to cleanup the Initializer before the interpreter finishes
     auto atexit_register = safe_import("atexit", "register");
     atexit_register(py::cpp_function([]() {
-        initializer->reset_contexts();
+        // During interpreter shutdown (esp. with gevent), heavy cleanup can
+        // trigger refcounting or Python API calls without a valid runtime.
+        // If gevent monkey-patching is active, skip setting the shutdown flag
+        // because it interferes with greenlet scheduling at exit.
+
+        bool gevent_active = false;
+        try {
+            auto is_patched = safe_import("gevent.monkey", "is_module_patched");
+            gevent_active =
+              asbool(is_patched("threading")) || asbool(is_patched("socket")) || asbool(is_patched("ssl"));
+        } catch (const py::error_already_set&) {
+            PyErr_Clear();
+        }
+
+        if (!gevent_active) {
+            py::gil_scoped_acquire gil; // safe to touch Python-adjacent state
+            TaintEngineContext::set_shutting_down(true);
+        }
+
         initializer.reset();
         if (taint_engine_context) {
             taint_engine_context->clear_all_request_context_slots();
@@ -83,8 +99,6 @@ PYBIND11_MODULE(_native, m)
     }));
 
     m.doc() = "Native Python module";
-
-    py::module m_initializer = pyexport_m_initializer(m);
     py::module m_appctx = pyexport_m_taint_engine_context(m);
     pyexport_m_taint_tracking(m);
 
