@@ -1,4 +1,6 @@
 from dataclasses import dataclass
+from typing import ClassVar
+from typing import Optional
 
 from ddtrace._trace.processor import SpanProcessor
 from ddtrace._trace.span import Span
@@ -14,6 +16,22 @@ log = get_logger(__name__)
 
 @dataclass(eq=False)
 class AppSecIastSpanProcessor(SpanProcessor):
+    _instance: ClassVar[Optional["AppSecIastSpanProcessor"]] = None
+
+    @classmethod
+    def enable(cls) -> None:
+        """Enable the IAST span processor."""
+        if cls._instance is None:
+            instance = cls._instance = cls()
+            instance.register()
+
+    @classmethod
+    def disable(cls) -> None:
+        """Disable the IAST span processor."""
+        if cls._instance is not None:
+            cls._instance.unregister()
+            cls._instance = None
+
     def __post_init__(self) -> None:
         from . import load_iast
 
