@@ -30,10 +30,10 @@ def _asm_manual_keep(span: Span) -> None:
 
     span.set_tag(constants.MANUAL_KEEP_KEY)
     # set decision maker to ASM = -5
-    span.set_tag_str(SAMPLING_DECISION_TRACE_TAG_KEY, "-%d" % SamplingMechanism.APPSEC)
+    span._set_tag_str(SAMPLING_DECISION_TRACE_TAG_KEY, "-%d" % SamplingMechanism.APPSEC)
 
     # set Security propagation tag
-    span.set_tag_str(APPSEC.PROPAGATION_HEADER, "02")
+    span._set_tag_str(APPSEC.PROPAGATION_HEADER, "02")
     span.context._meta[APPSEC.PROPAGATION_HEADER] = "02"
 
 
@@ -55,7 +55,7 @@ def _handle_metadata(entry_span: Span, prefix: str, metadata: dict) -> None:
         else:
             if isinstance(data, bool):
                 data = "true" if data else "false"
-            entry_span.set_tag_str(f"{prefix}", str(data))
+            entry_span._set_tag_str(f"{prefix}", str(data))
 
 
 def _track_user_login_common(
@@ -77,35 +77,35 @@ def _track_user_login_common(
         tag_prefix = "%s.%s" % (APPSEC.USER_LOGIN_EVENT_PREFIX, success_str)
 
         if success:
-            span.set_tag_str(APPSEC.USER_LOGIN_EVENT_SUCCESS_TRACK, "true")
+            span._set_tag_str(APPSEC.USER_LOGIN_EVENT_SUCCESS_TRACK, "true")
         else:
-            span.set_tag_str(APPSEC.USER_LOGIN_EVENT_FAILURE_TRACK, "true")
+            span._set_tag_str(APPSEC.USER_LOGIN_EVENT_FAILURE_TRACK, "true")
 
         # This is used to mark if the call was done from the SDK of the automatic login events
         if login_events_mode in (LOGIN_EVENTS_MODE.SDK, LOGIN_EVENTS_MODE.AUTO):
-            span.set_tag_str("%s.sdk" % tag_prefix, "true")
+            span._set_tag_str("%s.sdk" % tag_prefix, "true")
             reported_mode = asm_config._user_event_mode
         else:
             reported_mode = login_events_mode
 
         mode_tag = APPSEC.AUTO_LOGIN_EVENTS_SUCCESS_MODE if success else APPSEC.AUTO_LOGIN_EVENTS_FAILURE_MODE
-        span.set_tag_str(mode_tag, reported_mode)
+        span._set_tag_str(mode_tag, reported_mode)
 
         tag_metadata_prefix = "%s.%s" % (APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, success_str)
         if metadata is not None:
             _handle_metadata(span, tag_metadata_prefix, metadata)
 
         if login:
-            span.set_tag_str(f"{APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC}.{success_str}.usr.login", login)
+            span._set_tag_str(f"{APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC}.{success_str}.usr.login", login)
             if login_events_mode != LOGIN_EVENTS_MODE.SDK:
-                span.set_tag_str(APPSEC.USER_LOGIN_USERNAME, login)
-            span.set_tag_str("%s.login" % tag_prefix, login)
+                span._set_tag_str(APPSEC.USER_LOGIN_USERNAME, login)
+            span._set_tag_str("%s.login" % tag_prefix, login)
 
         if email:
-            span.set_tag_str("%s.email" % tag_prefix, email)
+            span._set_tag_str("%s.email" % tag_prefix, email)
 
         if name:
-            span.set_tag_str("%s.username" % tag_prefix, name)
+            span._set_tag_str("%s.username" % tag_prefix, name)
 
         _asm_manual_keep(span)
         return span
@@ -156,12 +156,12 @@ def track_user_login_success_event(
         return
     if real_mode == LOGIN_EVENTS_MODE.ANON and isinstance(user_id, str):
         user_id = _hash_user_id(user_id)
-    span.set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, real_mode)
+    span._set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, real_mode)
     if user_id:
         if login_events_mode != LOGIN_EVENTS_MODE.SDK:
-            span.set_tag_str(APPSEC.USER_LOGIN_USERID, str(user_id))
+            span._set_tag_str(APPSEC.USER_LOGIN_USERID, str(user_id))
         else:
-            span.set_tag_str(f"{APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC}.success.usr.id", str(user_id))
+            span._set_tag_str(f"{APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC}.success.usr.id", str(user_id))
     set_user(None, user_id or "", name, email, scope, role, session_id, propagate, span, may_block=False)
     if in_asm_context():
         custom_data = {
@@ -207,22 +207,22 @@ def track_user_login_failure_event(
         return
     if exists is not None:
         exists_str = "true" if exists else "false"
-        span.set_tag_str("%s.failure.%s" % (APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, user.EXISTS), exists_str)
+        span._set_tag_str("%s.failure.%s" % (APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, user.EXISTS), exists_str)
     if user_id:
         if real_mode == LOGIN_EVENTS_MODE.ANON and isinstance(user_id, str):
             user_id = _hash_user_id(user_id)
         if login_events_mode != LOGIN_EVENTS_MODE.SDK:
-            span.set_tag_str(APPSEC.USER_LOGIN_USERID, str(user_id))
-        span.set_tag_str("%s.failure.%s" % (APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, user.ID), str(user_id))
-    span.set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, real_mode)
+            span._set_tag_str(APPSEC.USER_LOGIN_USERID, str(user_id))
+        span._set_tag_str("%s.failure.%s" % (APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, user.ID), str(user_id))
+    span._set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, real_mode)
     # if called from the SDK, set the login, email and name
     if login_events_mode in (LOGIN_EVENTS_MODE.SDK, LOGIN_EVENTS_MODE.AUTO):
         if login:
-            span.set_tag_str("%s.failure.login" % APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, login)
+            span._set_tag_str("%s.failure.login" % APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, login)
         if email:
-            span.set_tag_str("%s.failure.email" % APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, email)
+            span._set_tag_str("%s.failure.email" % APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, email)
         if name:
-            span.set_tag_str("%s.failure.username" % APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, name)
+            span._set_tag_str("%s.failure.username" % APPSEC.USER_LOGIN_EVENT_PREFIX_PUBLIC, name)
     if in_asm_context():
         custom_data: dict[str, Any] = {"LOGIN_FAILURE": None}
         if login:
@@ -242,25 +242,25 @@ def track_user_signup_event(
     span = _asm_request_context.get_entry_span()
     if span:
         success_str = "true" if success else "false"
-        span.set_tag_str(APPSEC.USER_SIGNUP_EVENT, success_str)
+        span._set_tag_str(APPSEC.USER_SIGNUP_EVENT, success_str)
         if user_id:
             if login_events_mode == LOGIN_EVENTS_MODE.ANON and isinstance(user_id, str):
                 user_id = _hash_user_id(user_id)
-            span.set_tag_str(user.ID, str(user_id))
-            span.set_tag_str(APPSEC.USER_SIGNUP_EVENT_USERID, str(user_id))
-            span.set_tag_str(APPSEC.USER_LOGIN_USERID, str(user_id))
+            span._set_tag_str(user.ID, str(user_id))
+            span._set_tag_str(APPSEC.USER_SIGNUP_EVENT_USERID, str(user_id))
+            span._set_tag_str(APPSEC.USER_LOGIN_USERID, str(user_id))
         if login:
             if login_events_mode == LOGIN_EVENTS_MODE.ANON and isinstance(login, str):
                 login = _hash_user_id(login)
-            span.set_tag_str(APPSEC.USER_SIGNUP_EVENT_USERNAME, str(login))
-            span.set_tag_str(APPSEC.USER_LOGIN_USERNAME, str(login))
+            span._set_tag_str(APPSEC.USER_SIGNUP_EVENT_USERNAME, str(login))
+            span._set_tag_str(APPSEC.USER_LOGIN_USERNAME, str(login))
         _asm_manual_keep(span)
 
         # This is used to mark if the call was done from the SDK of the automatic login events
         if login_events_mode == LOGIN_EVENTS_MODE.SDK:
-            span.set_tag_str("%s.sdk" % APPSEC.USER_SIGNUP_EVENT, "true")
+            span._set_tag_str("%s.sdk" % APPSEC.USER_SIGNUP_EVENT, "true")
         else:
-            span.set_tag_str("%s.auto.mode" % APPSEC.USER_SIGNUP_EVENT_MODE, str(login_events_mode))
+            span._set_tag_str("%s.auto.mode" % APPSEC.USER_SIGNUP_EVENT_MODE, str(login_events_mode))
 
         return
     else:
@@ -298,7 +298,7 @@ def track_custom_event(tracer: Any, event_name: str, metadata: Dict[str, Any]) -
         )
         return
 
-    span.set_tag_str("%s.%s.track" % (APPSEC.CUSTOM_EVENT_PREFIX, event_name), "true")
+    span._set_tag_str("%s.%s.track" % (APPSEC.CUSTOM_EVENT_PREFIX, event_name), "true")
     if metadata:
         _handle_metadata(span, f"{APPSEC.CUSTOM_EVENT_PREFIX}.{event_name}", metadata)
     _asm_manual_keep(span)
@@ -365,14 +365,14 @@ def block_request_if_user_blocked(
         mode = asm_config._user_event_mode
     entry_span = _asm_request_context.get_entry_span()
     if entry_span:
-        entry_span.set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, mode)
+        entry_span._set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, mode)
         if userid:
             if mode == LOGIN_EVENTS_MODE.ANON:
                 userid = _hash_user_id(str(userid))
-            entry_span.set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, mode)
+            entry_span._set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, mode)
             if mode != LOGIN_EVENTS_MODE.SDK:
-                entry_span.set_tag_str(APPSEC.USER_LOGIN_USERID, str(userid))
-            entry_span.set_tag_str(user.ID, str(userid))
+                entry_span._set_tag_str(APPSEC.USER_LOGIN_USERID, str(userid))
+            entry_span._set_tag_str(user.ID, str(userid))
     if should_block_user(None, userid, session_id):
         _asm_request_context.block_request()
 
@@ -469,18 +469,18 @@ def _on_django_process(result_user, session_key, mode, kwargs, info_retriever, d
             hash_id = ""
             if isinstance(user_id, str):
                 hash_id = _hash_user_id(user_id)
-                span.set_tag_str(APPSEC.USER_LOGIN_USERID, hash_id)
+                span._set_tag_str(APPSEC.USER_LOGIN_USERID, hash_id)
             if isinstance(user_login, str):
                 hash_login = _hash_user_id(user_login)
-                span.set_tag_str(APPSEC.USER_LOGIN_USERNAME, hash_login)
-            span.set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, mode)
+                span._set_tag_str(APPSEC.USER_LOGIN_USERNAME, hash_login)
+            span._set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, mode)
             set_user(None, hash_id, propagate=True, may_block=False, span=span)
         elif mode == LOGIN_EVENTS_MODE.IDENT:
             if user_id:
-                span.set_tag_str(APPSEC.USER_LOGIN_USERID, str(user_id))
+                span._set_tag_str(APPSEC.USER_LOGIN_USERID, str(user_id))
             if user_login:
-                span.set_tag_str(APPSEC.USER_LOGIN_USERNAME, str(user_login))
-            span.set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, mode)
+                span._set_tag_str(APPSEC.USER_LOGIN_USERNAME, str(user_login))
+            span._set_tag_str(APPSEC.AUTO_LOGIN_EVENTS_COLLECTION_MODE, mode)
             set_user(
                 None,
                 str(user_id),
@@ -515,20 +515,20 @@ def _on_django_signup_user(django_config, pin, func, instance, args, kwargs, use
         if span is None:
             return
         _asm_manual_keep(span)
-        span.set_tag_str(APPSEC.USER_SIGNUP_EVENT_MODE, str(asm_config._user_event_mode))
-        span.set_tag_str(APPSEC.USER_SIGNUP_EVENT, "true")
+        span._set_tag_str(APPSEC.USER_SIGNUP_EVENT_MODE, str(asm_config._user_event_mode))
+        span._set_tag_str(APPSEC.USER_SIGNUP_EVENT, "true")
         if "login" in user_extra:
             login = user_extra["login"]
             if asm_config._user_event_mode == LOGIN_EVENTS_MODE.ANON:
                 login = _hash_user_id(login)
-            span.set_tag_str(APPSEC.USER_SIGNUP_EVENT_USERNAME, login)
-            span.set_tag_str(APPSEC.USER_LOGIN_USERNAME, login)
+            span._set_tag_str(APPSEC.USER_SIGNUP_EVENT_USERNAME, login)
+            span._set_tag_str(APPSEC.USER_LOGIN_USERNAME, login)
         if user_id:
             user_id = str(user_id)
             if asm_config._user_event_mode == LOGIN_EVENTS_MODE.ANON:
                 user_id = _hash_user_id(str(user_id))
-            span.set_tag_str(APPSEC.USER_SIGNUP_EVENT_USERID, user_id)
-            span.set_tag_str(APPSEC.USER_LOGIN_USERID, user_id)
+            span._set_tag_str(APPSEC.USER_SIGNUP_EVENT_USERID, user_id)
+            span._set_tag_str(APPSEC.USER_LOGIN_USERID, user_id)
 
 
 def listen():
