@@ -5,18 +5,22 @@ AI Guard public SDK
 from ._api_client import AIGuardAbortError
 from ._api_client import AIGuardClient
 from ._api_client import AIGuardClientError
-from ._api_client import AIGuardWorkflow
-from ._api_client import Prompt
+from ._api_client import Evaluation
+from ._api_client import Function
+from ._api_client import Message
+from ._api_client import Options
 from ._api_client import ToolCall
 from ._api_client import new_ai_guard_client
 
 
 __all__ = [
     "new_ai_guard_client",
-    "AIGuardWorkflow",
     "AIGuardClient",
     "AIGuardClientError",
     "AIGuardAbortError",
-    "Prompt",
+    "Evaluation",
+    "Function",
+    "Message",
+    "Options",
     "ToolCall",
 ]
