@@ -83,10 +83,10 @@ class WrappedClientResponseContentProxy(wrapt.ObjectProxy):
         operation_name = "{}.read".format(self._self_parent_span.name)
 
         with self._self_pin.tracer.start_span(operation_name, child_of=self._self_parent_span) as span:
-            span.set_tag_str(COMPONENT, config.aiobotocore.integration_name)
+            span._set_tag_str(COMPONENT, config.aiobotocore.integration_name)
 
             # set span.kind tag equal to type of request
-            span.set_tag_str(SPAN_KIND, SpanKind.CLIENT)
+            span._set_tag_str(SPAN_KIND, SpanKind.CLIENT)
 
             # inherit parent attributes
             span.resource = self._self_parent_span.resource
@@ -126,10 +126,10 @@ async def _wrapped_api_call(original_func, instance, args, kwargs):
         service=ext_service(pin, config.aiobotocore, default=schematize_service_name(fallback_service)),
         span_type=SpanTypes.HTTP,
     ) as span:
-        span.set_tag_str(COMPONENT, config.aiobotocore.integration_name)
+        span._set_tag_str(COMPONENT, config.aiobotocore.integration_name)
 
         # set span.kind tag equal to type of request
-        span.set_tag_str(SPAN_KIND, SpanKind.CLIENT)
+        span._set_tag_str(SPAN_KIND, SpanKind.CLIENT)
 
         # PERF: avoid setting via Span.set_tag
         span.set_metric(_SPAN_MEASURED_KEY, 1)
@@ -152,7 +152,7 @@ async def _wrapped_api_call(original_func, instance, args, kwargs):
             # Derive the peer hostname now that we have both service and region.
             hostname = _derive_peer_hostname(endpoint_name, region_name, params)
             if hostname:
-                span.set_tag_str("peer.service", hostname)
+                span._set_tag_str("peer.service", hostname)
 
         meta = {
             "aws.agent": "aiobotocore",
@@ -185,10 +185,10 @@ async def _wrapped_api_call(original_func, instance, args, kwargs):
 
         request_id = response_meta.get("RequestId")
         if request_id:
-            span.set_tag_str("aws.requestid", request_id)
+            span._set_tag_str("aws.requestid", request_id)
 
         request_id2 = response_headers.get("x-amz-id-2")
         if request_id2:
-            span.set_tag_str("aws.requestid2", request_id2)
+            span._set_tag_str("aws.requestid2", request_id2)
 
         return result
