@@ -110,7 +110,7 @@ def _extract_headers(scope: Mapping[str, Any]) -> Mapping[str, Any]:
 
 def _default_handle_exception_span(exc, span):
     """Default handler for exception for span"""
-    span.set_tag_str(http.STATUS_CODE, "500")
+    span._set_tag_str(http.STATUS_CODE, "500")
 
 
 def span_from_scope(scope: Mapping[str, Any]) -> Optional[Span]:
@@ -261,7 +261,9 @@ class TraceMiddleware:
             if not self.integration_config.trace_query_string:
                 query_string = None
             body = None
-            result = core.dispatch_with_results("asgi.request.parse.body", (receive, headers)).await_receive_and_body
+            result = core.dispatch_with_results(  # ast-grep-ignore: core-dispatch-with-results
+                "asgi.request.parse.body", (receive, headers)
+            ).await_receive_and_body
             if result:
                 receive, body = await result.value
 
@@ -285,7 +287,7 @@ class TraceMiddleware:
             )
             tags = _extract_versions_from_scope(scope, self.integration_config)
             for name, value in tags.items():
-                span.set_tag_str(name, value)
+                span._set_tag_str(name, value)
 
             @wraps(receive)
             async def wrapped_receive():
@@ -421,7 +423,9 @@ class TraceMiddleware:
                         span.finish()
 
             async def wrapped_blocked_send(message: Mapping[str, Any]):
-                result = core.dispatch_with_results("asgi.block.started", (ctx, url)).status_headers_content
+                result = core.dispatch_with_results(  # ast-grep-ignore: core-dispatch-with-results
+                    "asgi.block.started", (ctx, url)
+                ).status_headers_content
                 if result:
                     status, headers, content = result.value
                 else:
