@@ -7,6 +7,8 @@ from ddtrace import config
 from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.trace_utils import unwrap as _u
 from ddtrace.ext import SpanKind
+from ddtrace.ext import azure_eventhubs as azure_eventhubsx
+from ddtrace.ext import azure_servicebus as azure_servicebusx
 from ddtrace.internal.schema import schematize_service_name
 from ddtrace.internal.utils.formats import asbool
 from ddtrace.propagation.http import HTTPPropagator
@@ -71,10 +73,78 @@ def _patched_get_functions(wrapped, instance, args, kwargs):
             function._func = _wrap_timer_trigger(pin, func, function_name)
         elif trigger_type == "serviceBusTrigger":
             function._func = _wrap_service_bus_trigger(pin, func, function_name, trigger_arg_name, trigger_details)
+        elif trigger_type == "eventHubTrigger":
+            function._func = _wrap_event_hubs_trigger(pin, func, function_name, trigger_arg_name, trigger_details)
 
     return functions
 
 
+def _wrap_event_hubs_trigger(pin, func, function_name, trigger_arg_name, trigger_details):
+    trigger_type = "EventHubs"
+
+    def context_factory(kwargs):
+        resource_name = f"{trigger_type} {function_name}"
+        return create_context("azure.functions.patched_event_hubs", pin, resource_name)
+
+    def pre_dispatch(ctx, kwargs):
+        entity_name = trigger_details.get("eventHubName")
+        cardinality = trigger_details.get("cardinality")
+        msg_arg_value = kwargs.get(trigger_arg_name)
+
+        if (
+            cardinality == azure_functions.Cardinality.MANY
+            and isinstance(msg_arg_value, list)
+            and isinstance(msg_arg_value[0], azure_functions.EventHubEvent)
+        ):
+            batch_count = str(len(msg_arg_value))
+            metadata = getattr(msg_arg_value[0], "metadata", {})
+            fully_qualified_namespace = metadata.get("PartitionContext", {}).get("FullyQualifiedNamespace")
+            message_id = None
+
+            if config.azure_functions.distributed_tracing:
+                for properties in metadata.get("PropertiesArray", []):
+                    parent_context = HTTPPropagator.extract(properties)
+                    if parent_context.trace_id is not None and parent_context.span_id is not None:
+                        ctx.span.link_span(parent_context)
+        elif isinstance(msg_arg_value, azure_functions.EventHubEvent):
+            batch_count = None
+            metadata = getattr(msg_arg_value, "metadata", {})
+            fully_qualified_namespace = metadata.get("PartitionContext", {}).get("FullyQualifiedNamespace")
+            message_id = metadata.get("SystemProperties", {}).get("message-id")
+
+            if config.azure_functions.distributed_tracing:
+                parent_context = HTTPPropagator.extract(metadata.get("Properties", {}))
+                if (
+                    parent_context is not None
+                    and parent_context.trace_id is not None
+                    and parent_context.span_id is not None
+                ):
+                    ctx.span.link_span(parent_context)
+        else:
+            batch_count = None
+            fully_qualified_namespace = None
+            message_id = None
+
+        return (
+            "azure.functions.event_hubs_trigger_modifier",
+            (
+                ctx,
+                config.azure_functions,
+                function_name,
+                trigger_type,
+                SpanKind.CONSUMER,
+                azure_eventhubsx.RECEIVE,
+                azure_eventhubsx.SERVICE,
+                entity_name,
+                fully_qualified_namespace,
+                message_id,
+                batch_count,
+            ),
+        )
+
+    return wrap_function_with_tracing(func, context_factory, pre_dispatch=pre_dispatch)
+
+
 def _wrap_http_trigger(pin, func, function_name, trigger_arg_name):
     trigger_type = "Http"
 
@@ -144,6 +214,8 @@ def _wrap_service_bus_trigger(pin, func, function_name, trigger_arg_name, trigge
                 function_name,
                 trigger_type,
                 SpanKind.CONSUMER,
+                azure_servicebusx.RECEIVE,
+                azure_servicebusx.SERVICE,
                 entity_name,
                 fully_qualified_namespace,
                 message_id,
