@@ -1,18 +1,33 @@
+from typing import Any
+from typing import List
+from typing import Optional
+from typing import Tuple
 from typing import Union
 from uuid import UUID
 
 import azure.servicebus as azure_servicebus
+from azure.servicebus import ServiceBusMessage
+from azure.servicebus import ServiceBusMessageBatch
 import azure.servicebus.amqp as azure_servicebus_amqp
+from azure.servicebus.amqp import AmqpAnnotatedMessage
 
 from ddtrace import config
+from ddtrace._trace.pin import Pin
+from ddtrace._trace.span import Span
 from ddtrace.contrib.trace_utils import ext_service
 from ddtrace.ext import SpanTypes
+from ddtrace.ext import azure_servicebus as azure_servicebusx
 from ddtrace.internal import core
 from ddtrace.internal.utils import get_argument_value
 from ddtrace.propagation.http import HTTPPropagator
 
 
-def create_context(context_name, pin, operation_name, resource=None):
+def create_context(
+    context_name: str,
+    pin: Pin,
+    operation_name: str,
+    resource: Optional[str] = None,
+) -> core.ExecutionContext:
     return core.context_with_data(
         context_name,
         span_name=operation_name,
@@ -23,15 +38,21 @@ def create_context(context_name, pin, operation_name, resource=None):
     )
 
 
-def handle_service_bus_message_context(span, message_arg_value):
-    if isinstance(message_arg_value, (azure_servicebus.ServiceBusMessage, azure_servicebus_amqp.AmqpAnnotatedMessage)):
+def handle_service_bus_message_context(
+    span: Span,
+    message_arg_value: Union[
+        ServiceBusMessage,
+        AmqpAnnotatedMessage,
+        List[Union[ServiceBusMessage, AmqpAnnotatedMessage]],
+        ServiceBusMessageBatch,
+    ],
+):
+    if isinstance(message_arg_value, (ServiceBusMessage, AmqpAnnotatedMessage)):
         inject_context(span, message_arg_value)
     elif (
         isinstance(message_arg_value, list)
         and message_arg_value
-        and isinstance(
-            message_arg_value[0], (azure_servicebus.ServiceBusMessage, azure_servicebus_amqp.AmqpAnnotatedMessage)
-        )
+        and isinstance(message_arg_value[0], (ServiceBusMessage, AmqpAnnotatedMessage))
     ):
         for message in message_arg_value:
             inject_context(span, message)
@@ -42,7 +63,7 @@ def handle_service_bus_message_context(span, message_arg_value):
                 span.link_span(parent_context)
 
 
-def inject_context(span, message):
+def inject_context(span: Span, message: Union[ServiceBusMessage, AmqpAnnotatedMessage]):
     """
     ServiceBusMessage.application_properties is of type Dict[str | bytes, PrimitiveTypes] | None
     AmqpAnnotatedMessage.application_properties is of type Dict[str | bytes, Any] | None
@@ -61,7 +82,14 @@ def inject_context(span, message):
     message.application_properties.update(inject_carrier)
 
 
-def handle_service_bus_message_attributes(message_arg_value):
+def handle_service_bus_message_attributes(
+    message_arg_value: Union[
+        ServiceBusMessage,
+        AmqpAnnotatedMessage,
+        List[Union[ServiceBusMessage, AmqpAnnotatedMessage]],
+        ServiceBusMessageBatch,
+    ],
+) -> Tuple[Union[str, None], Union[str, None]]:
     if isinstance(message_arg_value, azure_servicebus.ServiceBusMessage):
         batch_count = None
         message_id = message_arg_value.message_id
@@ -80,16 +108,22 @@ def handle_service_bus_message_attributes(message_arg_value):
     elif isinstance(message_arg_value, list):
         batch_count = str(len(message_arg_value))
         message_id = None
-    else:
-        message_id = None
-        batch_count = None
     return message_id, batch_count
 
 
 def dispatch_message_modifier(
-    ctx, args, kwargs, message_operation, resource_name, fully_qualified_namespace, message_arg
+    ctx: core.ExecutionContext,
+    args: Any,
+    kwargs: Any,
+    message_operation: str,
+    resource_name: str,
+    fully_qualified_namespace: str,
+    message_arg: str,
 ):
     message_arg_value = get_argument_value(args, kwargs, 0, message_arg, True)
+    if message_arg_value is None:
+        return
+
     message_id, batch_count = handle_service_bus_message_attributes(message_arg_value)
 
     if config.azure_servicebus.distributed_tracing:
@@ -101,6 +135,7 @@ def dispatch_message_modifier(
             ctx,
             config.azure_servicebus,
             message_operation,
+            azure_servicebusx.SERVICE,
             resource_name,
             fully_qualified_namespace,
             message_id,
