@@ -15,20 +15,18 @@ from ddtrace.llmobs._constants import CACHE_READ_INPUT_TOKENS_METRIC_KEY
 from ddtrace.llmobs._constants import CACHE_WRITE_INPUT_TOKENS_METRIC_KEY
 from ddtrace.llmobs._integrations.base_stream_handler import StreamHandler
 from ddtrace.llmobs._integrations.base_stream_handler import make_traced_stream
+from ddtrace.llmobs._integrations.bedrock_utils import _AI21
+from ddtrace.llmobs._integrations.bedrock_utils import _AMAZON
+from ddtrace.llmobs._integrations.bedrock_utils import _ANTHROPIC
+from ddtrace.llmobs._integrations.bedrock_utils import _COHERE
+from ddtrace.llmobs._integrations.bedrock_utils import _META
+from ddtrace.llmobs._integrations.bedrock_utils import _STABILITY
 from ddtrace.llmobs._integrations.bedrock_utils import parse_model_id
 
 
 log = get_logger(__name__)
 
 
-_AI21 = "ai21"
-_AMAZON = "amazon"
-_ANTHROPIC = "anthropic"
-_COHERE = "cohere"
-_META = "meta"
-_STABILITY = "stability"
-
-
 def traced_stream_read(traced_stream, original_read, amt=None):
     """Wraps around method to tags the response data and finish the span as the user consumes the stream."""
     handler = traced_stream.handler
