@@ -106,9 +106,9 @@ class TraceTool(cherrypy.Tool):
             return
 
         span.error = 1
-        span.set_tag_str(ERROR_TYPE, str(cherrypy._cperror._exc_info()[0]))
-        span.set_tag_str(ERROR_MSG, str(cherrypy._cperror._exc_info()[1]))
-        span.set_tag_str(ERROR_STACK, cherrypy._cperror.format_exc())
+        span._set_tag_str(ERROR_TYPE, str(cherrypy._cperror._exc_info()[0]))
+        span._set_tag_str(ERROR_MSG, str(cherrypy._cperror._exc_info()[1]))
+        span._set_tag_str(ERROR_STACK, cherrypy._cperror.format_exc())
 
         self._close_span(span)
 
