@@ -85,6 +85,29 @@ Configuration
 
    Default: ``False``
 
+.. envvar:: DD_DJANGO_TRACING_MINIMAL
+
+   Enables minimal tracing mode for performance-sensitive applications. When enabled, this disables
+   Django ORM, cache, and template instrumentation while keeping middleware instrumentation enabled.
+   This can significantly reduce overhead by removing Django-specific spans while preserving visibility
+   into the underlying database drivers, cache clients, and other integrations.
+
+   This is equivalent to setting:
+   - ``DD_DJANGO_INSTRUMENT_TEMPLATES=false``
+   - ``DD_DJANGO_INSTRUMENT_DATABASES=false``
+   - ``DD_DJANGO_INSTRUMENT_CACHES=false``
+
+   For example, with ``DD_DJANGO_INSTRUMENT_DATABASES=false``, Django ORM query spans are disabled
+   but database driver spans (e.g., psycopg, MySQLdb) will still be created, providing visibility
+   into the actual database queries without the Django ORM overhead.
+
+   Consider using this option if your application is performance-sensitive and the additional
+   Django-layer spans are not required for your observability needs.
+
+   Default: ``False``
+
+   *New in version v3.15.0.*
+
 .. py:data:: ddtrace.config.django['instrument_middleware']
 
    Whether or not to instrument middleware.
