@@ -45,8 +45,8 @@ class _EndpointHook:
         endpoint = self.ENDPOINT_NAME
         if endpoint is None:
             endpoint = "%s" % getattr(instance, "OBJECT_NAME", "")
-        span.set_tag_str("openai.request.endpoint", "/%s/%s" % (API_VERSION, endpoint))
-        span.set_tag_str("openai.request.method", self.HTTP_METHOD_TYPE)
+        span._set_tag_str("openai.request.endpoint", "/%s/%s" % (API_VERSION, endpoint))
+        span._set_tag_str("openai.request.method", self.HTTP_METHOD_TYPE)
 
         if self._request_arg_params and len(self._request_arg_params) > 1:
             for idx, arg in enumerate(self._request_arg_params):
@@ -55,16 +55,16 @@ class _EndpointHook:
                 if arg is None or args[idx] is None:
                     continue
                 if arg in self._base_level_tag_args:
-                    span.set_tag_str("openai.%s" % arg, str(args[idx]))
+                    span._set_tag_str("openai.%s" % arg, str(args[idx]))
         for kw_attr in self._request_kwarg_params:
             if kw_attr not in kwargs:
                 continue
 
             if isinstance(kwargs[kw_attr], dict):
                 for k, v in kwargs[kw_attr].items():
-                    span.set_tag_str("openai.request.%s.%s" % (kw_attr, k), str(v))
+                    span._set_tag_str("openai.request.%s.%s" % (kw_attr, k), str(v))
             elif kw_attr == "engine" or kw_attr == "model":  # Azure OpenAI requires using "engine" instead of "model"
-                span.set_tag_str("openai.request.model", str(kwargs[kw_attr]))
+                span._set_tag_str("openai.request.model", str(kwargs[kw_attr]))
 
     def handle_request(self, pin, integration, instance, span, args, kwargs):
         self._record_request(pin, integration, instance, span, args, kwargs)
@@ -79,7 +79,7 @@ class _EndpointHook:
     def _record_response(self, pin, integration, span, args, kwargs, resp, error):
         for resp_attr in self._response_attrs:
             if hasattr(resp, resp_attr):
-                span.set_tag_str("openai.response.%s" % resp_attr, str(getattr(resp, resp_attr, "")))
+                span._set_tag_str("openai.response.%s" % resp_attr, str(getattr(resp, resp_attr, "")))
         return resp
 
 
@@ -220,6 +220,10 @@ class _ChatCompletionWithRawResponseHook(_ChatCompletionHook):
     pass
 
 
+class _ChatCompletionParseHook(_ChatCompletionHook):
+    OPERATION_ID = "parseChatCompletion"
+
+
 class _EmbeddingHook(_EndpointHook):
     _request_kwarg_params = ("model", "engine")
     _response_attrs = ("model",)
@@ -256,7 +260,8 @@ class _ListHook(_EndpointHook):
         resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
         if not resp:
             return
-        span.set_metric("openai.response.count", len(resp.data or []))
+        if hasattr(resp, "data"):
+            span.set_metric("openai.response.count", len(resp.data or []))
         return resp
 
 
@@ -309,16 +314,16 @@ class _RetrieveHook(_EndpointHook):
         if endpoint.endswith("/models"):
             span.resource = "retrieveModel"
             if len(args) >= 1:
-                span.set_tag_str("openai.request.model", args[0])
+                span._set_tag_str("openai.request.model", args[0])
             else:
-                span.set_tag_str("openai.request.model", kwargs.get("model", kwargs.get("id", "")))
+                span._set_tag_str("openai.request.model", kwargs.get("model", kwargs.get("id", "")))
         elif endpoint.endswith("/files"):
             span.resource = "retrieveFile"
             if len(args) >= 1:
-                span.set_tag_str("openai.request.file_id", args[0])
+                span._set_tag_str("openai.request.file_id", args[0])
             else:
-                span.set_tag_str("openai.request.file_id", kwargs.get("file_id", kwargs.get("id", "")))
-        span.set_tag_str("openai.request.endpoint", "%s/*" % endpoint)
+                span._set_tag_str("openai.request.file_id", kwargs.get("file_id", kwargs.get("id", "")))
+        span._set_tag_str("openai.request.endpoint", "%s/*" % endpoint)
 
     def _record_response(self, pin, integration, span, args, kwargs, resp, error):
         resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
@@ -358,16 +363,16 @@ class _DeleteHook(_EndpointHook):
         if endpoint.endswith("/models"):
             span.resource = "deleteModel"
             if len(args) >= 1:
-                span.set_tag_str("openai.request.model", args[0])
+                span._set_tag_str("openai.request.model", args[0])
             else:
-                span.set_tag_str("openai.request.model", kwargs.get("model", kwargs.get("sid", "")))
+                span._set_tag_str("openai.request.model", kwargs.get("model", kwargs.get("sid", "")))
         elif endpoint.endswith("/files"):
             span.resource = "deleteFile"
             if len(args) >= 1:
-                span.set_tag_str("openai.request.file_id", args[0])
+                span._set_tag_str("openai.request.file_id", args[0])
             else:
-                span.set_tag_str("openai.request.file_id", kwargs.get("file_id", kwargs.get("sid", "")))
-        span.set_tag_str("openai.request.endpoint", "%s/*" % endpoint)
+                span._set_tag_str("openai.request.file_id", kwargs.get("file_id", kwargs.get("sid", "")))
+        span._set_tag_str("openai.request.endpoint", "%s/*" % endpoint)
 
     def _record_response(self, pin, integration, span, args, kwargs, resp, error):
         resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
@@ -375,12 +380,12 @@ class _DeleteHook(_EndpointHook):
             return
         if hasattr(resp, "data"):
             if resp._headers.get("openai-organization"):
-                span.set_tag_str("openai.organization.name", resp._headers.get("openai-organization"))
-            span.set_tag_str("openai.response.id", resp.data.get("id", ""))
-            span.set_tag_str("openai.response.deleted", str(resp.data.get("deleted", "")))
+                span._set_tag_str("openai.organization.name", resp._headers.get("openai-organization"))
+            span._set_tag_str("openai.response.id", resp.data.get("id", ""))
+            span._set_tag_str("openai.response.deleted", str(resp.data.get("deleted", "")))
         else:
-            span.set_tag_str("openai.response.id", str(resp.id))
-            span.set_tag_str("openai.response.deleted", str(resp.deleted))
+            span._set_tag_str("openai.response.id", str(resp.id))
+            span._set_tag_str("openai.response.deleted", str(resp.deleted))
         return resp
 
 
@@ -407,7 +412,7 @@ class _ImageHook(_EndpointHook):
 
     def _record_request(self, pin, integration, instance, span, args, kwargs):
         super()._record_request(pin, integration, instance, span, args, kwargs)
-        span.set_tag_str("openai.request.model", "dall-e")
+        span._set_tag_str("openai.request.model", "dall-e")
 
 
 class _ImageCreateHook(_ImageHook):
@@ -475,9 +480,9 @@ class _FileCreateHook(_BaseFileHook):
         super()._record_request(pin, integration, instance, span, args, kwargs)
         fp = args[0] if len(args) >= 1 else kwargs.get("file", "")
         if fp and hasattr(fp, "name"):
-            span.set_tag_str("openai.request.filename", fp.name.split("/")[-1])
+            span._set_tag_str("openai.request.filename", fp.name.split("/")[-1])
         else:
-            span.set_tag_str("openai.request.filename", "")
+            span._set_tag_str("openai.request.filename", "")
 
     def _record_response(self, pin, integration, span, args, kwargs, resp, error):
         resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
@@ -492,7 +497,7 @@ class _FileDownloadHook(_BaseFileHook):
 
     def _record_request(self, pin, integration, instance, span, args, kwargs):
         super()._record_request(pin, integration, instance, span, args, kwargs)
-        span.set_tag_str("openai.request.file_id", args[0] if len(args) >= 1 else kwargs.get("file_id", ""))
+        span._set_tag_str("openai.request.file_id", args[0] if len(args) >= 1 else kwargs.get("file_id", ""))
 
     def _record_response(self, pin, integration, span, args, kwargs, resp, error):
         resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
@@ -522,3 +527,7 @@ class _ResponseHook(_BaseCompletionHook):
             return self._handle_streamed_response(integration, span, kwargs, resp, operation_type="response")
         integration.llmobs_set_tags(span, args=[], kwargs=kwargs, response=resp, operation="response")
         return resp
+
+
+class _ResponseParseHook(_ResponseHook):
+    OPERATION_ID = "parseResponse"
