@@ -10,6 +10,7 @@ from ddtrace.contrib.dbapi import TracedConnection
 from ddtrace.contrib.internal.trace_utils import _convert_to_string
 from ddtrace.ext import db
 from ddtrace.ext import net
+from ddtrace.internal.compat import is_wrapted
 from ddtrace.internal.schema import schematize_database_operation
 from ddtrace.internal.schema import schematize_service_name
 from ddtrace.internal.utils.formats import asbool
@@ -52,7 +53,7 @@ def patch():
 
 
 def unpatch():
-    if isinstance(pymysql.connect, wrapt.ObjectProxy):
+    if is_wrapted(pymysql.connect):
         pymysql.connect = pymysql.connect.__wrapped__
     pymysql._datadog_patch = False
 
