@@ -71,6 +71,7 @@ RAY_SERVICE_NAME = os.environ.get(RAY_JOB_NAME)
 RAY_MODULE_DENYLIST = {
     "ray.dag",
     "ray.experimental",
+    "ray.data._internal",
 }
 
 
@@ -130,13 +131,13 @@ def _wrap_task_execution(wrapped, *args, **kwargs):
 
             result = wrapped(*args, **kwargs)
 
-            task_execute_span.set_tag_str(RAY_TASK_STATUS, RAY_STATUS_SUCCESS)
+            task_execute_span._set_tag_str(RAY_TASK_STATUS, RAY_STATUS_SUCCESS)
             return result
         except BaseException as e:
             log.debug(
                 "Ray task %s execution failed: %s", f"{wrapped.__module__}.{wrapped.__qualname__}", e, exc_info=True
             )
-            task_execute_span.set_tag_str(RAY_TASK_STATUS, RAY_STATUS_ERROR)
+            task_execute_span._set_tag_str(RAY_TASK_STATUS, RAY_STATUS_ERROR)
             raise
 
 
@@ -152,10 +153,11 @@ def traced_submit_task(wrapped, instance, args, kwargs):
     # This is done under a lock as multiple task could be submit at the same time
     # and thus try to modify the signature as the same time
     with instance._inject_lock:
-        if instance._function_signature is None:
+        if not getattr(instance._function, "_dd_trace_wrapped", False):
             instance._function = _wrap_remote_function_execution(instance._function)
             instance._function.__signature__ = _inject_dd_trace_ctx_kwarg(instance._function)
             instance._function_signature = extract_signature(instance._function)
+            instance._function._dd_trace_wrapped = True
 
     with tracer.trace(
         "task.submit",
@@ -163,22 +165,26 @@ def traced_submit_task(wrapped, instance, args, kwargs):
         service=RAY_SERVICE_NAME,
         span_type=SpanTypes.RAY,
     ) as span:
-        span.set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
+        span._set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
         _inject_ray_span_tags_and_metrics(span)
 
         try:
             if config.ray.trace_args_kwargs:
                 set_tag_or_truncate(span, RAY_TASK_ARGS, kwargs.get("args", {}))
                 set_tag_or_truncate(span, RAY_TASK_KWARGS, kwargs.get("kwargs", {}))
-            _inject_context_in_kwargs(span.context, kwargs)
+
+            # Check if signature has the trace context parameter
+            has_trace_ctx = DD_RAY_TRACE_CTX in inspect.signature(instance._function).parameters
+            if has_trace_ctx:
+                _inject_context_in_kwargs(span.context, kwargs)
 
             resp = wrapped(*args, **kwargs)
 
-            span.set_tag_str(RAY_TASK_SUBMIT_STATUS, RAY_STATUS_SUCCESS)
+            span._set_tag_str(RAY_TASK_SUBMIT_STATUS, RAY_STATUS_SUCCESS)
             return resp
         except BaseException as e:
             log.debug("Failed to submit Ray task %s : %s", f"{instance._function_name}.remote()", e, exc_info=True)
-            span.set_tag_str(RAY_TASK_SUBMIT_STATUS, RAY_STATUS_ERROR)
+            span._set_tag_str(RAY_TASK_SUBMIT_STATUS, RAY_STATUS_ERROR)
             raise e
 
 
@@ -212,9 +218,9 @@ def traced_submit_job(wrapped, instance, args, kwargs):
     try:
         # Root span creation
         _inject_ray_span_tags_and_metrics(job_span)
-        job_span.set_tag_str(RAY_SUBMISSION_ID_TAG, submission_id)
+        job_span._set_tag_str(RAY_SUBMISSION_ID_TAG, submission_id)
         if entrypoint:
-            job_span.set_tag_str(RAY_ENTRYPOINT, entrypoint)
+            job_span._set_tag_str(RAY_ENTRYPOINT, entrypoint)
 
         metadata = kwargs.get("metadata", {})
         dot_paths = flatten_metadata_dict(metadata)
@@ -228,8 +234,8 @@ def traced_submit_job(wrapped, instance, args, kwargs):
             "ray.job.submit", service=job_name or DEFAULT_JOB_NAME, span_type=SpanTypes.RAY
         ) as submit_span:
             _inject_ray_span_tags_and_metrics(submit_span)
-            submit_span.set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
-            submit_span.set_tag_str(RAY_SUBMISSION_ID_TAG, submission_id)
+            submit_span._set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
+            submit_span._set_tag_str(RAY_SUBMISSION_ID_TAG, submission_id)
 
             # Inject the context of the job so that ray.job.run is its child
             runtime_env = kwargs.get("runtime_env") or {}
@@ -244,14 +250,14 @@ def traced_submit_job(wrapped, instance, args, kwargs):
 
             try:
                 resp = wrapped(*args, **kwargs)
-                submit_span.set_tag_str(RAY_JOB_SUBMIT_STATUS, RAY_STATUS_SUCCESS)
+                submit_span._set_tag_str(RAY_JOB_SUBMIT_STATUS, RAY_STATUS_SUCCESS)
                 return resp
             except BaseException as e:
                 log.debug("Failed to submit Ray Job %s : %s", job_name, e, exc_info=True)
-                submit_span.set_tag_str(RAY_JOB_SUBMIT_STATUS, RAY_STATUS_ERROR)
+                submit_span._set_tag_str(RAY_JOB_SUBMIT_STATUS, RAY_STATUS_ERROR)
                 raise
     except BaseException as e:
-        job_span.set_tag_str(RAY_JOB_STATUS, RAY_STATUS_ERROR)
+        job_span._set_tag_str(RAY_JOB_STATUS, RAY_STATUS_ERROR)
         job_span.error = 1
         job_span.set_exc_info(type(e), e, e.__traceback__)
         stop_long_running_job(submission_id)
@@ -282,7 +288,7 @@ def traced_actor_method_call(wrapped, instance, args, kwargs):
         span_type=SpanTypes.RAY,
         resource=f"{actor_name}.{method_name}.remote",
     ) as span:
-        span.set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
+        span._set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
         if config.ray.trace_args_kwargs:
             set_tag_or_truncate(span, RAY_ACTOR_METHOD_ARGS, get_argument_value(args, kwargs, 0, "args"))
             set_tag_or_truncate(span, RAY_ACTOR_METHOD_KWARGS, get_argument_value(args, kwargs, 1, "kwargs"))
@@ -309,13 +315,13 @@ def traced_get(wrapped, instance, args, kwargs):
         child_of=tracer.context_provider.active(),
         activate=True,
     ) as span:
-        span.set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
+        span._set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
         timeout = kwargs.get("timeout")
         if timeout is not None:
-            span.set_tag_str("ray.get.timeout_s", str(timeout))
+            span._set_tag_str("ray.get.timeout_s", str(timeout))
         _inject_ray_span_tags_and_metrics(span)
         get_value = get_argument_value(args, kwargs, 0, "object_refs")
-        span.set_tag_str(RAY_GET_VALUE_SIZE_BYTES, str(sys.getsizeof(get_value)))
+        span._set_tag_str(RAY_GET_VALUE_SIZE_BYTES, str(sys.getsizeof(get_value)))
         return wrapped(*args, **kwargs)
 
 
@@ -330,12 +336,12 @@ def traced_put(wrapped, instance, args, kwargs):
         tracer.context_provider.activate(_extract_tracing_context_from_env())
 
     with tracer.trace("ray.put", service=RAY_SERVICE_NAME or DEFAULT_JOB_NAME, span_type=SpanTypes.RAY) as span:
-        span.set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
+        span._set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
         _inject_ray_span_tags_and_metrics(span)
 
         put_value = get_argument_value(args, kwargs, 0, "value")
-        span.set_tag_str(RAY_PUT_VALUE_TYPE, str(type(put_value).__name__))
-        span.set_tag_str(RAY_PUT_VALUE_SIZE_BYTES, str(sys.getsizeof(put_value)))
+        span._set_tag_str(RAY_PUT_VALUE_TYPE, str(type(put_value).__name__))
+        span._set_tag_str(RAY_PUT_VALUE_SIZE_BYTES, str(sys.getsizeof(put_value)))
 
         return wrapped(*args, **kwargs)
 
@@ -358,18 +364,18 @@ def traced_wait(wrapped, instance, args, kwargs):
         child_of=tracer.context_provider.active(),
         activate=True,
     ) as span:
-        span.set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
+        span._set_tag_str(SPAN_KIND, SpanKind.PRODUCER)
         _inject_ray_span_tags_and_metrics(span)
 
         timeout = kwargs.get("timeout")
         num_returns = kwargs.get("num_returns")
         fetch_local = kwargs.get("fetch_local")
         if timeout is not None:
-            span.set_tag_str(RAY_WAIT_TIMEOUT, str(timeout))
+            span._set_tag_str(RAY_WAIT_TIMEOUT, str(timeout))
         if num_returns is not None:
-            span.set_tag_str(RAY_WAIT_NUM_RETURNS, str(num_returns))
+            span._set_tag_str(RAY_WAIT_NUM_RETURNS, str(num_returns))
         if fetch_local is not None:
-            span.set_tag_str(RAY_WAIT_FETCH_LOCAL, str(fetch_local))
+            span._set_tag_str(RAY_WAIT_FETCH_LOCAL, str(fetch_local))
         return wrapped(*args, **kwargs)
 
 
@@ -426,7 +432,7 @@ def _exec_entrypoint_wrapper(method: Callable[..., Any]) -> Any:
             service=os.environ.get(RAY_JOB_NAME, DEFAULT_JOB_NAME),
             span_type=SpanTypes.RAY,
         ) as span:
-            span.set_tag_str(SPAN_KIND, SpanKind.CONSUMER)
+            span._set_tag_str(SPAN_KIND, SpanKind.CONSUMER)
             _inject_ray_span_tags_and_metrics(span)
 
             return method(self, *args, **kwargs)
@@ -494,6 +500,10 @@ def inject_tracing_into_actor_class(wrapped, instance, args, kwargs):
     if any(module_name.startswith(denied_module) for denied_module in RAY_MODULE_DENYLIST):
         return cls
 
+    # Actor beginning with _ are considered internal and will not be traced
+    if class_name.startswith("_"):
+        return cls
+
     # Determine if the class is a JobSupervisor
     is_job_supervisor = f"{module_name}.{class_name}" == "ray.dashboard.modules.job.job_supervisor.JobSupervisor"
     # We do not want to instrument ping and polling to remove noise
