@@ -47,7 +47,7 @@ def _supported_versions() -> Dict[str, str]:
 class _SFTracedCursor(TracedCursor):
     def _set_post_execute_tags(self, span):
         super(_SFTracedCursor, self)._set_post_execute_tags(span)
-        span.set_tag_str("sfqid", self.__wrapped__.sfqid)
+        span._set_tag_str("sfqid", self.__wrapped__.sfqid)
 
 
 def patch():
