@@ -28,7 +28,7 @@ def generate(func, renderer, args, kwargs):
     with pin.tracer.trace(
         "tornado.template", service=pin.service, resource=resource, span_type=SpanTypes.TEMPLATE
     ) as span:
-        span.set_tag_str(COMPONENT, config.tornado.integration_name)
+        span._set_tag_str(COMPONENT, config.tornado.integration_name)
 
-        span.set_tag_str("tornado.template_name", template_name)
+        span._set_tag_str("tornado.template_name", template_name)
         return func(*args, **kwargs)
