@@ -106,7 +106,7 @@ def _store_headers(headers, span, integration_config, request_or_response):
         if tag_name is None:
             continue
         # An empty tag defaults to a http.<request or response>.headers.<header name> tag
-        span.set_tag_str(tag_name or _normalize_tag_name(request_or_response, header_name), header_value)
+        span._set_tag_str(tag_name or _normalize_tag_name(request_or_response, header_name), header_value)
 
 
 def _get_request_header_referrer_host(headers, headers_are_case_sensitive=False):
@@ -429,17 +429,17 @@ def set_http_meta(
          { "id": <int_value> }
     """
     if method is not None:
-        span.set_tag_str(http.METHOD, method)
+        span._set_tag_str(http.METHOD, method)
 
     if url is not None:
         url = _sanitized_url(url)
         _set_url_tag(integration_config, span, url, query)
 
     if target_host is not None:
-        span.set_tag_str(net.TARGET_HOST, target_host)
+        span._set_tag_str(net.TARGET_HOST, target_host)
 
     if server_address is not None:
-        span.set_tag_str(net.SERVER_ADDRESS, server_address)
+        span._set_tag_str(net.SERVER_ADDRESS, server_address)
 
     if status_code is not None:
         try:
@@ -447,26 +447,26 @@ def set_http_meta(
         except (TypeError, ValueError):
             log.debug("failed to convert http status code %r to int", status_code)
         else:
-            span.set_tag_str(http.STATUS_CODE, str(status_code))
+            span._set_tag_str(http.STATUS_CODE, str(status_code))
             if config._http_server.is_error_code(int_status_code):
                 span.error = 1
 
     if status_msg is not None:
-        span.set_tag_str(http.STATUS_MSG, status_msg)
+        span._set_tag_str(http.STATUS_MSG, status_msg)
 
     if query is not None and integration_config.trace_query_string:
-        span.set_tag_str(http.QUERY_STRING, query)
+        span._set_tag_str(http.QUERY_STRING, query)
 
     request_ip = peer_ip
     if request_headers:
         user_agent = _get_request_header_user_agent(request_headers, headers_are_case_sensitive)
         if user_agent:
-            span.set_tag_str(http.USER_AGENT, user_agent)
+            span._set_tag_str(http.USER_AGENT, user_agent)
 
         # Extract referrer host if referer header is present
         referrer_host = _get_request_header_referrer_host(request_headers, headers_are_case_sensitive)
         if referrer_host:
-            span.set_tag_str(http.REFERRER_HOSTNAME, referrer_host)
+            span._set_tag_str(http.REFERRER_HOSTNAME, referrer_host)
 
         # We always collect the IP if appsec is enabled to report it on potential vulnerabilities.
         # https://datadoghq.atlassian.net/wiki/spaces/APS/pages/2118779066/Client+IP+addresses+resolution
@@ -481,8 +481,8 @@ def set_http_meta(
                 )
 
             if request_ip:
-                span.set_tag_str(http.CLIENT_IP, request_ip)
-                span.set_tag_str("network.client.ip", request_ip)
+                span._set_tag_str(http.CLIENT_IP, request_ip)
+                span._set_tag_str("network.client.ip", request_ip)
 
         if integration_config.is_header_tracing_configured:
             """We should store both http.<request_or_response>.headers.<header_name> and
@@ -494,7 +494,7 @@ def set_http_meta(
         _store_response_headers(dict(response_headers), span, integration_config)
 
     if retries_remain is not None:
-        span.set_tag_str(http.RETRIES_REMAIN, str(retries_remain))
+        span._set_tag_str(http.RETRIES_REMAIN, str(retries_remain))
 
     core.dispatch(
         "set_http_meta_for_asm",
@@ -516,7 +516,7 @@ def set_http_meta(
     )
 
     if route is not None:
-        span.set_tag_str(http.ROUTE, route)
+        span._set_tag_str(http.ROUTE, route)
 
 
 def activate_distributed_headers(tracer, int_config=None, request_headers=None, override=None):
@@ -576,16 +576,16 @@ def _copy_trace_level_tags(target_span: Span, parent: Span):
     """
     for key, value in parent.context._baggage.items():
         target_span.context.set_baggage_item(key, value)
-        target_span.set_tag_str(f"baggage.{key}", value)
+        target_span._set_tag_str(f"baggage.{key}", value)
 
     if parent.context.sampling_priority is not None:
         target_span.context.sampling_priority = parent.context.sampling_priority
 
     if parent.context._meta.get(_ORIGIN_KEY):
-        target_span.set_tag_str(_ORIGIN_KEY, parent.context._meta[_ORIGIN_KEY])
+        target_span._set_tag_str(_ORIGIN_KEY, parent.context._meta[_ORIGIN_KEY])
 
     if parent.context._meta.get(SAMPLING_DECISION_TRACE_TAG_KEY):
-        target_span.set_tag_str(SAMPLING_DECISION_TRACE_TAG_KEY, parent.context._meta[SAMPLING_DECISION_TRACE_TAG_KEY])
+        target_span._set_tag_str(SAMPLING_DECISION_TRACE_TAG_KEY, parent.context._meta[SAMPLING_DECISION_TRACE_TAG_KEY])
 
 
 def _flatten(
