@@ -235,11 +235,11 @@ def _install_routine(patch_routine, patch_class, patch_mod, config):
                 service=trace_utils.ext_service(pin, config),
                 span_type=conf.get("span_type"),
             ) as span:
-                span.set_tag_str(COMPONENT, config.integration_name)
-                span.set_tag_str(dbx.SYSTEM, "vertica")
+                span._set_tag_str(COMPONENT, config.integration_name)
+                span._set_tag_str(dbx.SYSTEM, "vertica")
 
                 # set span.kind to the type of operation being performed
-                span.set_tag_str(SPAN_KIND, SpanKind.CLIENT)
+                span._set_tag_str(SPAN_KIND, SpanKind.CLIENT)
 
                 if conf.get("measured", False):
                     # PERF: avoid setting via Span.set_tag
