@@ -1,5 +1,4 @@
 from dataclasses import dataclass
-from functools import partial
 from itertools import count
 import sys
 from threading import current_thread
@@ -17,13 +16,13 @@ from ddtrace.debugging._probe.model import LogFunctionProbe
 from ddtrace.debugging._probe.model import LogLineProbe
 from ddtrace.debugging._probe.model import ProbeEvalTiming
 from ddtrace.debugging._session import Session
-from ddtrace.debugging._signal.collector import SignalCollector
 from ddtrace.debugging._signal.snapshot import Snapshot
 from ddtrace.debugging._uploader import SignalUploader
 from ddtrace.debugging._uploader import UploaderProduct
 from ddtrace.ext import EXIT_SPAN_TYPES
-from ddtrace.internal import core
 from ddtrace.internal.compat import Path
+from ddtrace.internal.forksafe import Lock
+from ddtrace.internal.logger import get_logger
 from ddtrace.internal.packages import is_user_code
 from ddtrace.internal.safety import _isinstance
 from ddtrace.internal.wrapping.context import WrappingContext
@@ -31,6 +30,9 @@ from ddtrace.settings.code_origin import config as co_config
 from ddtrace.trace import Span
 
 
+log = get_logger(__name__)
+
+
 def frame_stack(frame: FrameType) -> t.Iterator[FrameType]:
     _frame: t.Optional[FrameType] = frame
     while _frame is not None:
@@ -38,15 +40,6 @@ def frame_stack(frame: FrameType) -> t.Iterator[FrameType]:
         _frame = _frame.f_back
 
 
-def wrap_entrypoint(collector: SignalCollector, f: t.Callable) -> None:
-    if not _isinstance(f, FunctionType):
-        return
-
-    _f = t.cast(FunctionType, f)
-    if not EntrySpanWrappingContext.is_wrapped(_f):
-        EntrySpanWrappingContext(collector, _f).wrap()
-
-
 @dataclass
 class EntrySpanProbe(LogFunctionProbe):
     __span_class__ = "entry"
@@ -118,12 +111,13 @@ class EntrySpanLocation:
 
 
 class EntrySpanWrappingContext(WrappingContext):
+    __enabled__ = False
     __priority__ = 199
 
-    def __init__(self, collector: SignalCollector, f: FunctionType) -> None:
+    def __init__(self, uploader: t.Type[SignalUploader], f: FunctionType) -> None:
         super().__init__(f)
 
-        self.collector = collector
+        self.uploader = uploader
 
         filename = str(Path(f.__code__.co_filename).resolve())
         name = f.__qualname__
@@ -139,26 +133,30 @@ class EntrySpanWrappingContext(WrappingContext):
     def __enter__(self):
         super().__enter__()
 
-        root = ddtrace.tracer.current_root_span()
-        span = ddtrace.tracer.current_span()
-        location = self.location
-        if root is None or span is None or root.get_tag("_dd.entry_location.file") is not None:
-            return self
+        if self.__enabled__:
+            root = ddtrace.tracer.current_root_span()
+            span = ddtrace.tracer.current_span()
+            location = self.location
+            if root is None or span is None or root.get_tag("_dd.entry_location.file") is not None:
+                return self
 
-        # Add tags to the local root
-        for s in (root, span):
-            s.set_tag_str("_dd.code_origin.type", "entry")
+            # Add tags to the local root
+            for s in (root, span):
+                s._set_tag_str("_dd.code_origin.type", "entry")
 
-            s.set_tag_str("_dd.code_origin.frames.0.file", location.file)
-            s.set_tag_str("_dd.code_origin.frames.0.line", str(location.line))
-            s.set_tag_str("_dd.code_origin.frames.0.type", location.module)
-            s.set_tag_str("_dd.code_origin.frames.0.method", location.name)
+                s._set_tag_str("_dd.code_origin.frames.0.file", location.file)
+                s._set_tag_str("_dd.code_origin.frames.0.line", str(location.line))
+                s._set_tag_str("_dd.code_origin.frames.0.type", location.module)
+                s._set_tag_str("_dd.code_origin.frames.0.method", location.name)
 
-        self.set("start_time", monotonic_ns())
+            self.set("start_time", monotonic_ns())
 
         return self
 
     def _close_signal(self, retval=None, exc_info=(None, None, None)):
+        if not self.__enabled__:
+            return
+
         root = ddtrace.tracer.current_root_span()
         span = ddtrace.tracer.current_span()
         if root is None or span is None:
@@ -166,7 +164,13 @@ class EntrySpanWrappingContext(WrappingContext):
 
         # Check if we have any level 2 debugging sessions running for the
         # current trace
-        if any(s.level >= 2 for s in Session.from_trace()):
+        if any(s.level >= 2 for s in Session.from_trace(root.context or span.context)):
+            try:
+                start_time: int = self.get("start_time")
+            except KeyError:
+                # Context was not opened
+                return
+
             # Create a snapshot
             snapshot = Snapshot(
                 probe=self.location.probe,
@@ -179,12 +183,13 @@ class EntrySpanWrappingContext(WrappingContext):
             snapshot.do_enter()
 
             # Correlate the snapshot with the span
-            root.set_tag_str("_dd.code_origin.frames.0.snapshot_id", snapshot.uuid)
-            span.set_tag_str("_dd.code_origin.frames.0.snapshot_id", snapshot.uuid)
+            root._set_tag_str("_dd.code_origin.frames.0.snapshot_id", snapshot.uuid)
+            span._set_tag_str("_dd.code_origin.frames.0.snapshot_id", snapshot.uuid)
 
-            snapshot.do_exit(retval, exc_info, monotonic_ns() - self.get("start_time"))
+            snapshot.do_exit(retval, exc_info, monotonic_ns() - start_time)
 
-            self.collector.push(snapshot)
+            if (collector := self.uploader.get_collector()) is not None:
+                collector.push(snapshot)
 
     def __return__(self, retval):
         self._close_signal(retval=retval)
@@ -195,42 +200,68 @@ class EntrySpanWrappingContext(WrappingContext):
         super().__exit__(exc_type, exc_value, traceback)
 
 
-@dataclass
 class SpanCodeOriginProcessorEntry:
     __uploader__ = SignalUploader
+    __context_wrapper__ = EntrySpanWrappingContext
 
     _instance: t.Optional["SpanCodeOriginProcessorEntry"] = None
-    _handler: t.Optional[t.Callable] = None
+
+    _pending: t.List = []
+    _lock = Lock()
+
+    @classmethod
+    def instrument_view(cls, f):
+        if not _isinstance(f, FunctionType):
+            return
+
+        with cls._lock:
+            if cls._instance is None:
+                # Entry span code origin is not enabled, so we defer the
+                # instrumentation
+                cls._pending.append(f)
+                return
+
+        _f = t.cast(FunctionType, f)
+        if not EntrySpanWrappingContext.is_wrapped(_f):
+            log.debug("Patching entrypoint %r for code origin", f)
+            EntrySpanWrappingContext(cls.__uploader__, _f).wrap()
 
     @classmethod
     def enable(cls):
         if cls._instance is not None:
             return
 
-        cls._instance = cls()
+        with cls._lock:
+            cls._instance = cls()
+
+            # Instrument the pending views
+            while cls._pending:
+                cls.instrument_view(cls._pending.pop())
 
         # Register code origin for span with the snapshot uploader
-        cls.__uploader__.register(UploaderProduct.CODE_ORIGIN_SPAN)
+        cls.__uploader__.register(UploaderProduct.CODE_ORIGIN_SPAN_ENTRY)
 
-        # Register the entrypoint wrapping for entry spans
-        cls._handler = handler = partial(wrap_entrypoint, cls.__uploader__.get_collector())
-        core.on("service_entrypoint.patch", handler)
+        # Enable the context wrapper
+        cls.__context_wrapper__.__enabled__ = True
+
+        log.debug("Code Origin for Spans (entry) enabled")
 
     @classmethod
     def disable(cls):
         if cls._instance is None:
             return
 
-        # Unregister the entrypoint wrapping for entry spans
-        core.reset_listeners("service_entrypoint.patch", cls._handler)
+        # Disable the context wrapper
+        cls.__context_wrapper__.__enabled__ = False
+
         # Unregister code origin for span with the snapshot uploader
-        cls.__uploader__.unregister(UploaderProduct.CODE_ORIGIN_SPAN)
+        cls.__uploader__.unregister(UploaderProduct.CODE_ORIGIN_SPAN_ENTRY)
 
-        cls._handler = None
         cls._instance = None
 
+        log.debug("Code Origin for Spans (entry) disabled")
+
 
-@dataclass
 class SpanCodeOriginProcessorExit(SpanProcessor):
     __uploader__ = SignalUploader
 
@@ -240,7 +271,7 @@ class SpanCodeOriginProcessorExit(SpanProcessor):
         if span.span_type not in EXIT_SPAN_TYPES:
             return
 
-        span.set_tag_str("_dd.code_origin.type", "exit")
+        span._set_tag_str("_dd.code_origin.type", "exit")
 
         # Add call stack information to the exit span. Report only the part of
         # the stack that belongs to user code.
@@ -254,8 +285,8 @@ class SpanCodeOriginProcessorExit(SpanProcessor):
                 if n >= co_config.max_user_frames:
                     break
 
-                span.set_tag_str(f"_dd.code_origin.frames.{n}.file", filename)
-                span.set_tag_str(f"_dd.code_origin.frames.{n}.line", str(code.co_firstlineno))
+                span._set_tag_str(f"_dd.code_origin.frames.{n}.file", filename)
+                span._set_tag_str(f"_dd.code_origin.frames.{n}.line", str(code.co_firstlineno))
 
                 # Get the module and function name from the frame and code object. In Python3.11+ qualname
                 # is available, otherwise we'll fallback to the unqualified name.
@@ -265,12 +296,12 @@ class SpanCodeOriginProcessorExit(SpanProcessor):
                     name = code.co_name
 
                 mod = frame.f_globals.get("__name__")
-                span.set_tag_str(f"_dd.code_origin.frames.{n}.type", mod) if mod else None
-                span.set_tag_str(f"_dd.code_origin.frames.{n}.method", name) if name else None
+                span._set_tag_str(f"_dd.code_origin.frames.{n}.type", mod) if mod else None
+                span._set_tag_str(f"_dd.code_origin.frames.{n}.method", name) if name else None
 
                 # Check if we have any level 2 debugging sessions running for
                 # the current trace
-                if any(s.level >= 2 for s in Session.from_trace()):
+                if any(s.level >= 2 for s in Session.from_trace(span.context)):
                     # Create a snapshot
                     snapshot = Snapshot(
                         probe=ExitSpanProbe.from_frame(frame),
@@ -283,10 +314,11 @@ class SpanCodeOriginProcessorExit(SpanProcessor):
                     snapshot.do_line()
 
                     # Collect
-                    self.__uploader__.get_collector().push(snapshot)
+                    if (collector := self.__uploader__.get_collector()) is not None:
+                        collector.push(snapshot)
 
                     # Correlate the snapshot with the span
-                    span.set_tag_str(f"_dd.code_origin.frames.{n}.snapshot_id", snapshot.uuid)
+                    span._set_tag_str(f"_dd.code_origin.frames.{n}.snapshot_id", snapshot.uuid)
 
     def on_span_finish(self, span: Span) -> None:
         pass
@@ -299,11 +331,13 @@ class SpanCodeOriginProcessorExit(SpanProcessor):
         instance = cls._instance = cls()
 
         # Register code origin for span with the snapshot uploader
-        cls.__uploader__.register(UploaderProduct.CODE_ORIGIN_SPAN)
+        cls.__uploader__.register(UploaderProduct.CODE_ORIGIN_SPAN_EXIT)
 
         # Register the processor for exit spans
         instance.register()
 
+        log.debug("Code Origin for Spans (exit) enabled")
+
     @classmethod
     def disable(cls):
         if cls._instance is None:
@@ -313,6 +347,8 @@ class SpanCodeOriginProcessorExit(SpanProcessor):
         cls._instance.unregister()
 
         # Unregister code origin for span with the snapshot uploader
-        cls.__uploader__.unregister(UploaderProduct.CODE_ORIGIN_SPAN)
+        cls.__uploader__.unregister(UploaderProduct.CODE_ORIGIN_SPAN_EXIT)
 
         cls._instance = None
+
+        log.debug("Code Origin for Spans (exit) disabled")
