@@ -31,15 +31,15 @@ from ddtrace.settings._telemetry import config as telemetry_config
 from ddtrace.trace import Tracer  # noqa: F401
 
 from .. import telemetry
+from ..evp_proxy.constants import EVP_PROXY_AGENT_BASE_PATH
+from ..evp_proxy.constants import EVP_SUBDOMAIN_HEADER_API_VALUE
+from ..evp_proxy.constants import EVP_SUBDOMAIN_HEADER_NAME
 from ..utils.http import Response
 from ..utils.http import get_connection
 from ..utils.http import verify_url
 from ..utils.time import StopWatch
 from .constants import AGENTLESS_API_KEY_HEADER_NAME
 from .constants import AGENTLESS_DEFAULT_SITE
-from .constants import EVP_PROXY_AGENT_BASE_PATH
-from .constants import EVP_SUBDOMAIN_HEADER_API_VALUE
-from .constants import EVP_SUBDOMAIN_HEADER_NAME
 from .constants import GIT_API_BASE_PATH
 from .constants import REQUESTS_MODE
 from .telemetry.constants import ERROR_TYPES
