@@ -17,6 +17,9 @@ from ddtrace.settings._agent import config as agent_config
 from ddtrace.vendor.dogstatsd import DogStatsd  # noqa:F401
 
 from .. import service
+from ..evp_proxy.constants import EVP_PROXY_AGENT_ENDPOINT
+from ..evp_proxy.constants import EVP_SUBDOMAIN_HEADER_COVERAGE_VALUE
+from ..evp_proxy.constants import EVP_SUBDOMAIN_HEADER_NAME
 from ..runtime import get_runtime_id
 from ..writer import HTTPWriter
 from ..writer import WriterClientBase
@@ -25,10 +28,7 @@ from .constants import AGENTLESS_COVERAGE_BASE_URL
 from .constants import AGENTLESS_COVERAGE_ENDPOINT
 from .constants import AGENTLESS_DEFAULT_SITE
 from .constants import AGENTLESS_ENDPOINT
-from .constants import EVP_PROXY_AGENT_ENDPOINT
 from .constants import EVP_PROXY_COVERAGE_ENDPOINT
-from .constants import EVP_SUBDOMAIN_HEADER_COVERAGE_VALUE
-from .constants import EVP_SUBDOMAIN_HEADER_NAME
 from .encoder import CIVisibilityCoverageEncoderV02
 from .encoder import CIVisibilityEncoderV01
 from .telemetry.payload import REQUEST_ERROR_TYPE
