@@ -51,8 +51,8 @@ def _should_configure_metrics_exporter() -> bool:
 
     if API_VERSION < MINIMUM_SUPPORTED_VERSION:
         log.warning(
-            "OpenTelemetry API requires version %s or higher to enable logs collection. Found version %s. "
-            "Please upgrade the opentelemetry-api package before enabling ddtrace OpenTelemetry Logs support.",
+            "OpenTelemetry API requires version %s or higher to enable metrics collection. Found version %s. "
+            "Please upgrade the opentelemetry-api package before enabling ddtrace OpenTelemetry Metrics support.",
             ".".join(str(x) for x in MINIMUM_SUPPORTED_VERSION),
             ".".join(str(x) for x in API_VERSION),
         )
@@ -185,8 +185,8 @@ def _initialize_metrics(exporter_class, protocol, resource):
         from opentelemetry.sdk._configuration import _init_metrics
 
         # Ensure metrics exporter is configured to send payloads to a Datadog Agent.
-        # The default endpoint is resolved using the hostname from DD_AGENT.. and DD_TRACE_AGENT_... configs
-        os.environ["OTEL_EXPORTER_OTLP_METRICS_ENDPOINT"] = otel_config.exporter.METRICS_ENDPOINT
+        if "OTEL_EXPORTER_OTLP_ENDPOINT" not in os.environ and "OTEL_EXPORTER_OTLP_METRICS_ENDPOINT" not in os.environ:
+            os.environ["OTEL_EXPORTER_OTLP_METRICS_ENDPOINT"] = otel_config.exporter.METRICS_ENDPOINT
         os.environ[
             "OTEL_EXPORTER_OTLP_METRICS_TEMPORALITY_PREFERENCE"
         ] = otel_config.exporter.METRICS_TEMPORALITY_PREFERENCE
