@@ -26,4 +26,4 @@ class BaseServiceProcessor(TraceProcessor):
         return trace
 
     def _update_dd_base_service(self, span):
-        span.set_tag_str(key=_BASE_SERVICE_KEY, value=self._global_service)
+        span._set_tag_str(key=_BASE_SERVICE_KEY, value=self._global_service)
