@@ -74,19 +74,15 @@ def set_argument_value(
 
 def _get_metas_to_propagate(context):
     # type: (Any) -> List[Tuple[str, str]]
-    metas_to_propagate = []
-    # copying context._meta.items() to avoid RuntimeError: dictionary changed size during iteration
-    for k, v in list(context._meta.items()):
-        if isinstance(k, str) and k.startswith("_dd.p."):
-            metas_to_propagate.append((k, v))
-    return metas_to_propagate
+    # Using list comprehension for improved performance and memory efficiency
+    return [(k, v) for k, v in context._meta.items() if isinstance(k, str) and k.startswith("_dd.p.")]
 
 
 def get_blocked() -> Optional[Dict[str, Any]]:
     # local import to avoid circular dependency
     from ddtrace.internal import core
 
-    res = core.dispatch_with_results("asm.get_blocked")
+    res = core.dispatch_with_results("asm.get_blocked")  # ast-grep-ignore: core-dispatch-with-results
     if res and res.block_config:
         return res.block_config.value
     return None
