@@ -3,7 +3,7 @@ from typing import Callable  # noqa:F401
 from typing import Optional  # noqa:F401
 from typing import TypeVar  # noqa:F401
 
-import wrapt
+from ddtrace.internal.compat import is_wrapted
 
 
 F = TypeVar("F", bound=Callable[..., Any])
@@ -14,7 +14,7 @@ def iswrapped(obj, attr=None):
     """Returns whether an attribute is wrapped or not."""
     if attr is not None:
         obj = getattr(obj, attr, None)
-    return (hasattr(obj, "__wrapped__") and isinstance(obj, wrapt.ObjectProxy)) or hasattr(obj, "__dd_wrapped__")
+    return (hasattr(obj, "__wrapped__") and is_wrapted(obj)) or hasattr(obj, "__dd_wrapped__")
 
 
 def unwrap(obj, attr):
