@@ -4,15 +4,10 @@ from typing import Any  # noqa:F401
 from typing import Callable  # noqa:F401
 from typing import Dict  # noqa:F401
 from typing import Optional  # noqa:F401
+from typing import Protocol  # noqa:F401
 from typing import Tuple  # noqa:F401
 from typing import cast  # noqa:F401
 
-
-try:
-    from typing import Protocol  # noqa:F401
-except ImportError:
-    from typing_extensions import Protocol  # type: ignore[assignment]
-
 import bytecode as bc
 from bytecode import Instr
 
