@@ -10,6 +10,7 @@ from ._experiment import Dataset
 from ._experiment import DatasetRecord
 from ._llmobs import LLMObs
 from ._llmobs import LLMObsSpan
+from .types import Prompt
 
 
-__all__ = ["LLMObs", "LLMObsSpan", "Dataset", "DatasetRecord"]
+__all__ = ["LLMObs", "LLMObsSpan", "Dataset", "DatasetRecord", "Prompt"]
