@@ -2,6 +2,7 @@ from .anthropic import AnthropicIntegration
 from .base import BaseLLMIntegration
 from .bedrock import BedrockIntegration
 from .gemini import GeminiIntegration
+from .google_adk import GoogleAdkIntegration
 from .google_genai import GoogleGenAIIntegration
 from .langchain import LangChainIntegration
 from .litellm import LiteLLMIntegration
@@ -15,6 +16,7 @@ __all__ = [
     "BaseLLMIntegration",
     "BedrockIntegration",
     "GeminiIntegration",
+    "GoogleAdkIntegration",
     "GoogleGenAIIntegration",
     "LangChainIntegration",
     "LiteLLMIntegration",
