@@ -29,6 +29,12 @@ from ddtrace.settings.profiling import config
 from ddtrace.trace import Tracer
 
 
+ACQUIRE_RELEASE_CO_NAMES: frozenset[str] = frozenset(["_acquire", "_release"])
+ENTER_EXIT_CO_NAMES: frozenset[str] = frozenset(
+    ["acquire", "release", "__enter__", "__exit__", "__aenter__", "__aexit__"]
+)
+
+
 def _current_thread() -> Tuple[int, str]:
     thread_id: int = _thread.get_ident()
     return thread_id, _threading.get_thread_name(thread_id)
@@ -69,12 +75,15 @@ class _ProfiledLock(wrapt.ObjectProxy):
         self._self_acquired_at: int = 0
         self._self_name: Optional[str] = None
 
+    def acquire(self, *args: Any, **kwargs: Any) -> Any:
+        return self._acquire(self.__wrapped__.acquire, *args, **kwargs)
+
+    def __enter__(self, *args: Any, **kwargs: Any) -> Any:
+        return self._acquire(self.__wrapped__.__enter__, *args, **kwargs)
+
     def __aenter__(self, *args: Any, **kwargs: Any) -> Any:
         return self._acquire(self.__wrapped__.__aenter__, *args, **kwargs)
 
-    def __aexit__(self, *args: Any, **kwargs: Any) -> Any:
-        return self._release(self.__wrapped__.__aexit__, *args, **kwargs)
-
     def _acquire(self, inner_func: Callable[..., Any], *args: Any, **kwargs: Any) -> Any:
         if not self._self_capture_sampler.capture():
             return inner_func(*args, **kwargs)
@@ -83,55 +92,27 @@ class _ProfiledLock(wrapt.ObjectProxy):
         try:
             return inner_func(*args, **kwargs)
         finally:
+            end: int = time.monotonic_ns()
+            self._self_acquired_at = end
             try:
-                end: int = time.monotonic_ns()
-                self._self_acquired_at = end
-
-                thread_id: int
-                thread_name: str
-                thread_id, thread_name = _current_thread()
-
-                task_id: Optional[int]
-                task_name: Optional[str]
-                task_frame: Optional[FrameType]
-                task_id, task_name, task_frame = _task.get_task(thread_id)
-
                 self._maybe_update_self_name()
-                lock_name: str = (
-                    "%s:%s" % (self._self_init_loc, self._self_name) if self._self_name else self._self_init_loc
-                )
-
-                frame: FrameType
-                if task_frame is None:
-                    # If we can't get the task frame, we use the caller frame. We expect acquire/release or
-                    # __enter__/__exit__ to be on the stack, so we go back 2 frames.
-                    frame = sys._getframe(2)
-                else:
-                    frame = task_frame
-
-                frames: List[DDFrame]
-                frames, _ = _traceback.pyframe_to_frames(frame, self._self_max_nframes)
-
-                thread_native_id: int = _threading.get_thread_native_id(thread_id)
-
-                handle: ddup.SampleHandle = ddup.SampleHandle()
-                handle.push_monotonic_ns(end)
-                handle.push_lock_name(lock_name)
-                handle.push_acquire(end - start, 1)  # AFAICT, capture_pct does not adjust anything here
-                handle.push_threadinfo(thread_id, thread_native_id, thread_name)
-                handle.push_task_id(task_id)
-                handle.push_task_name(task_name)
-
-                if self._self_tracer is not None:
-                    handle.push_span(self._self_tracer.current_span())
-                for ddframe in frames:
-                    handle.push_frame(ddframe.function_name, ddframe.file_name, 0, ddframe.lineno)
-                handle.flush_sample()
+                self._flush_sample(start, end, is_acquire=True)
+            except AssertionError:
+                if config.enable_asserts:
+                    # AssertionError exceptions need to propagate
+                    raise
             except Exception:
+                # Instrumentation must never crash user code
                 pass  # nosec
 
-    def acquire(self, *args: Any, **kwargs: Any) -> Any:
-        return self._acquire(self.__wrapped__.acquire, *args, **kwargs)
+    def release(self, *args: Any, **kwargs: Any) -> Any:
+        return self._release(self.__wrapped__.release, *args, **kwargs)
+
+    def __exit__(self, *args: Any, **kwargs: Any) -> None:
+        self._release(self.__wrapped__.__exit__, *args, **kwargs)
+
+    def __aexit__(self, *args: Any, **kwargs: Any) -> Any:
+        return self._release(self.__wrapped__.__aexit__, *args, **kwargs)
 
     def _release(self, inner_func: Callable[..., Any], *args: Any, **kwargs: Any) -> None:
         # The underlying threading.Lock class is implemented using C code, and
@@ -151,59 +132,61 @@ class _ProfiledLock(wrapt.ObjectProxy):
         except AttributeError:
             # We just ignore the error, if the attribute is not found.
             pass
+
         try:
             return inner_func(*args, **kwargs)
         finally:
             if start is not None:
-                end: int = time.monotonic_ns()
+                self._flush_sample(start, end=time.monotonic_ns(), is_acquire=False)
 
-                thread_id: int
-                thread_name: str
-                thread_id, thread_name = _current_thread()
+    def _flush_sample(self, start: int, end: int, is_acquire: bool) -> None:
+        """Helper method to push lock profiling data to ddup.
 
-                task_id: Optional[int]
-                task_name: Optional[str]
-                task_frame: Optional[FrameType]
-                task_id, task_name, task_frame = _task.get_task(thread_id)
+        Args:
+            start: Start timestamp in nanoseconds
+            end: End timestamp in nanoseconds
+            is_acquire: True for acquire operations, False for release operations
+        """
+        handle: ddup.SampleHandle = ddup.SampleHandle()
 
-                lock_name: str = (
-                    "%s:%s" % (self._self_init_loc, self._self_name) if self._self_name else self._self_init_loc
-                )
+        handle.push_monotonic_ns(end)
 
-                frame: FrameType
-                if task_frame is None:
-                    # See the comments in _acquire
-                    frame = sys._getframe(2)
-                else:
-                    frame = task_frame
+        lock_name: str = f"{self._self_init_loc}:{self._self_name}" if self._self_name else self._self_init_loc
+        handle.push_lock_name(lock_name)
 
-                frames: List[DDFrame]
-                frames, _ = _traceback.pyframe_to_frames(frame, self._self_max_nframes)
+        duration_ns: int = end - start
+        if is_acquire:
+            handle.push_acquire(duration_ns, 1)
+        else:
+            handle.push_release(duration_ns, 1)
 
-                thread_native_id: int = _threading.get_thread_native_id(thread_id)
+        thread_id: int
+        thread_name: str
+        thread_id, thread_name = _current_thread()
 
-                handle: ddup.SampleHandle = ddup.SampleHandle()
-                handle.push_monotonic_ns(end)
-                handle.push_lock_name(lock_name)
-                handle.push_release(end - start, 1)  # AFAICT, capture_pct does not adjust anything here
-                handle.push_threadinfo(thread_id, thread_native_id, thread_name)
-                handle.push_task_id(task_id)
-                handle.push_task_name(task_name)
+        task_id: Optional[int]
+        task_name: Optional[str]
+        task_frame: Optional[FrameType]
+        task_id, task_name, task_frame = _task.get_task(thread_id)
 
-                if self._self_tracer is not None:
-                    handle.push_span(self._self_tracer.current_span())
-                for ddframe in frames:
-                    handle.push_frame(ddframe.function_name, ddframe.file_name, 0, ddframe.lineno)
-                handle.flush_sample()
+        handle.push_task_id(task_id)
+        handle.push_task_name(task_name)
 
-    def release(self, *args: Any, **kwargs: Any) -> Any:
-        return self._release(self.__wrapped__.release, *args, **kwargs)
+        thread_native_id: int = _threading.get_thread_native_id(thread_id)
+        handle.push_threadinfo(thread_id, thread_native_id, thread_name)
 
-    def __enter__(self, *args: Any, **kwargs: Any) -> Any:
-        return self._acquire(self.__wrapped__.__enter__, *args, **kwargs)
+        if self._self_tracer is not None:
+            handle.push_span(self._self_tracer.current_span())
 
-    def __exit__(self, *args: Any, **kwargs: Any) -> None:
-        self._release(self.__wrapped__.__exit__, *args, **kwargs)
+        # If we can't get the task frame, we use the caller frame.
+        # Call stack: 0: _flush_sample, 1: _acquire/_release, 2: acquire/release/__enter__/__exit__, 3: caller
+        frame: FrameType = task_frame or sys._getframe(3)
+        frames: List[DDFrame]
+        frames, _ = _traceback.pyframe_to_frames(frame, self._self_max_nframes)
+        for ddframe in frames:
+            handle.push_frame(ddframe.function_name, ddframe.file_name, 0, ddframe.lineno)
+
+        handle.flush_sample()
 
     def _find_self_name(self, var_dict: Dict[str, Any]) -> Optional[str]:
         for name, value in var_dict.items():
@@ -230,33 +213,23 @@ class _ProfiledLock(wrapt.ObjectProxy):
         # 3: caller frame
         if config.enable_asserts:
             frame: FrameType = sys._getframe(1)
-            # TODO: replace dict with list
-            if frame.f_code.co_name not in {"_acquire", "_release"}:
-                raise AssertionError("Unexpected frame %s" % frame.f_code.co_name)
+            if frame.f_code.co_name not in ACQUIRE_RELEASE_CO_NAMES:
+                raise AssertionError(f"Unexpected frame in stack: '{frame.f_code.co_name}'")
+
             frame = sys._getframe(2)
-            if frame.f_code.co_name not in {
-                "acquire",
-                "release",
-                "__enter__",
-                "__exit__",
-                "__aenter__",
-                "__aexit__",
-            }:
-                raise AssertionError("Unexpected frame %s" % frame.f_code.co_name)
-        frame = sys._getframe(3)
+            if frame.f_code.co_name not in ENTER_EXIT_CO_NAMES:
+                raise AssertionError(f"Unexpected frame in stack: '{frame.f_code.co_name}'")
 
         # First, look at the local variables of the caller frame, and then the global variables
-        self._self_name = self._find_self_name(frame.f_locals) or self._find_self_name(frame.f_globals)
-
-        if not self._self_name:
-            self._self_name = ""
+        frame = sys._getframe(3)
+        self._self_name = self._find_self_name(frame.f_locals) or self._find_self_name(frame.f_globals) or ""
 
 
 class FunctionWrapper(wrapt.FunctionWrapper):
     # Override the __get__ method: whatever happens, _allocate_lock is always considered by Python like a "static"
     # method, even when used as a class attribute. Python never tried to "bind" it to a method, because it sees it is a
     # builtin function. Override default wrapt behavior here that tries to detect bound method.
-    def __get__(self, instance: Any, owner: Optional[Type] = None) -> FunctionWrapper:
+    def __get__(self, instance: Any, owner: Optional[Type] = None) -> FunctionWrapper:  # type: ignore
         return self
 
 
