@@ -1,6 +1,14 @@
 #ifndef _DDTRACE_MEMALLOC_PYMACRO
 #define _DDTRACE_MEMALLOC_PYMACRO
 
+#if PY_VERSION_HEX >= 0x030c0000
+#define _PY312_AND_LATER
+#endif
+
+#if PY_VERSION_HEX >= 0x030a0000
+#define _PY310_AND_LATER
+#endif
+
 #if PY_VERSION_HEX >= 0x03090000
 #define _PY39_AND_LATER
 #endif
