@@ -148,11 +148,11 @@ impl TraceExporterBuilderPy {
         heartbeat_ms: u64,
         runtime_id: String,
     ) -> PyResult<Py<Self>> {
-        slf.try_as_mut()?.enable_telemetry(Some(TelemetryConfig {
+        slf.try_as_mut()?.enable_telemetry(TelemetryConfig {
             heartbeat: heartbeat_ms,
             runtime_id: Some(runtime_id),
             debug_enabled: true,
-        }));
+        });
         Ok(slf.into())
     }
 
