@@ -1372,6 +1372,44 @@ class Contrib_TestClass_For_Threats:
             else:
                 assert value is None
 
+    @pytest.mark.parametrize("apisec_enabled", [True, False])
+    def test_api_custom_scanners(self, interface: Interface, get_entry_span_tag, apisec_enabled):
+        import base64
+        import gzip
+
+        from ddtrace.ext import http
+
+        magic_key = "weqpfdjwlekfjowekhgfjiew"
+
+        with override_global_config(
+            dict(
+                _asm_enabled=True,
+                _api_security_enabled=apisec_enabled,
+                _asm_static_rule_file=rules.RULES_CUSTOM_SCANNERS,
+            )
+        ):
+            self.update_tracer(interface)
+            response = interface.client.get("/", headers={magic_key: "A0000B1111C2222"})
+            assert self.status(response) == 200
+            assert get_entry_span_tag(http.STATUS_CODE) == "200"
+            assert asm_config._api_security_enabled == apisec_enabled
+
+            value = get_entry_span_tag("_dd.appsec.s.req.headers")
+            if apisec_enabled:
+                assert value
+                api = json.loads(gzip.decompress(base64.b64decode(value)).decode())
+                assert isinstance(api, list)
+                assert api
+                headers = api[0]
+                assert magic_key in headers
+                assert headers[magic_key][1] == {
+                    "type": "custom_type",
+                    "category": "custom_category",
+                    "custom": "custom_data",
+                }
+            else:
+                assert value is None
+
     @pytest.mark.parametrize("apisec_enabled", [True, False])
     @pytest.mark.parametrize("priority", ["keep", "drop"])
     @pytest.mark.parametrize("delay", [0.0, 120.0])
@@ -1645,7 +1683,13 @@ class Contrib_TestClass_For_Threats:
                 # assert mocked.call_args_list == []
                 expected_rule_type = "command_injection" if endpoint == "shell_injection" else endpoint
                 expected_variant = (
-                    "exec" if endpoint == "command_injection" else "shell" if endpoint == "shell_injection" else None
+                    "exec"
+                    if endpoint == "command_injection"
+                    else "shell"
+                    if endpoint == "shell_injection"
+                    else "request"
+                    if endpoint == "ssrf"
+                    else None
                 )
                 matches = [t for c, n, t in telemetry_calls if c == "count" and n == "appsec.rasp.rule.match"]
                 # import delayed to get the correct version
