@@ -23,16 +23,14 @@ from ddtrace.appsec._iast._ast.ast_patching import astpatch_module
 from ddtrace.appsec._iast._ast.ast_patching import iastpatch
 from ddtrace.appsec._iast._ast.ast_patching import initialize_iast_lists
 from ddtrace.appsec._iast._iast_request_context import get_iast_reporter
-from ddtrace.appsec._iast._iast_request_context_base import end_iast_context
-from ddtrace.appsec._iast._iast_request_context_base import set_iast_request_enabled
-from ddtrace.appsec._iast._iast_request_context_base import start_iast_context
+from ddtrace.appsec._iast._iast_request_context_base import _iast_finish_request
+from ddtrace.appsec._iast._iast_request_context_base import _iast_start_request
 from ddtrace.appsec._iast.main import patch_iast
 from ddtrace.appsec._iast.sampling.vulnerability_detection import _reset_global_limit
 
 
 # Check if the log contains "iast::" to raise an error if that’s the case BUT, if the logs contains
-# "iast::instrumentation::" or "iast::instrumentation::"
-# are valid
+# "iast::instrumentation::" or "iast::instrumentation::" are valid
 IAST_VALID_LOG = re.compile(r"^iast::(?!instrumentation::|propagation::context::|propagation::sink_point).*$")
 
 
@@ -123,25 +121,22 @@ def iast_hypothesis_test(func):
 
 
 def _get_iast_data():
+    data = {}
     span_report = get_iast_reporter()
-    data = span_report.build_and_scrub_value_parts()
+    if span_report:
+        data = span_report.build_and_scrub_value_parts()
     return data
 
 
 def _start_iast_context_and_oce(span=None):
     oce.reconfigure()
-    request_iast_enabled = False
-    if oce.acquire_request(span):
-        start_iast_context()
-        request_iast_enabled = True
-
-    set_iast_request_enabled(request_iast_enabled)
+    return _iast_start_request(span)
 
 
 def _end_iast_context_and_oce(span=None):
-    end_iast_context(span)
-    oce.release_request()
+    result = _iast_finish_request(span)
     _reset_global_limit()
+    return result
 
 
 def load_iast_report(span):
