@@ -14,6 +14,7 @@ from ddtrace.appsec._iast.sampling.vulnerability_detection import init_request_v
 from ddtrace.appsec._iast.sampling.vulnerability_detection import reset_request_vulnerabilities
 from ddtrace.appsec._iast.sampling.vulnerability_detection import should_process_vulnerability
 from ddtrace.appsec._iast.sampling.vulnerability_detection import update_global_vulnerability_limit
+from ddtrace.appsec._iast.taint_sinks._base import VulnerabilityBase
 from tests.appsec.iast.iast_utils import _end_iast_context_and_oce
 from tests.appsec.iast.iast_utils import _start_iast_context_and_oce
 from tests.utils import override_global_config
@@ -292,3 +293,10 @@ def test_with_modified_max_vulnerabilities_config():
         # Global map should be updated with all processed vulnerabilities
         update_global_vulnerability_limit()
         assert len(_get_global_limit()["GET:/config_test"]) == 3
+
+
+def test_quota_out_of_context():
+    _end_iast_context_and_oce()
+    env = _get_iast_env()
+    assert env is None
+    assert VulnerabilityBase.has_quota() is False
