@@ -1,40 +1,38 @@
 # -*- coding: utf-8 -*-
 from ast import literal_eval
 import asyncio
-import logging
 from multiprocessing.pool import ThreadPool
 import random
-import re
 import sys
 from time import sleep
 
 import pytest
 
+from ddtrace.appsec._iast._iast_request_context_base import _get_iast_context_id
+from ddtrace.appsec._iast._iast_request_context_base import _num_objects_tainted_in_request
 from ddtrace.appsec._iast._taint_tracking import OriginType
 from ddtrace.appsec._iast._taint_tracking import Source
 from ddtrace.appsec._iast._taint_tracking import TaintRange
 from ddtrace.appsec._iast._taint_tracking import are_all_text_all_ranges
-from ddtrace.appsec._iast._taint_tracking import debug_taint_map
 from ddtrace.appsec._iast._taint_tracking import get_range_by_hash
 from ddtrace.appsec._iast._taint_tracking import get_ranges
-from ddtrace.appsec._iast._taint_tracking import num_objects_tainted
 from ddtrace.appsec._iast._taint_tracking import set_ranges
 from ddtrace.appsec._iast._taint_tracking import shift_taint_range
 from ddtrace.appsec._iast._taint_tracking import shift_taint_ranges
-from ddtrace.appsec._iast._taint_tracking._context import create_context
-from ddtrace.appsec._iast._taint_tracking._context import reset_context
-from ddtrace.appsec._iast._taint_tracking._context import reset_contexts
+from ddtrace.appsec._iast._taint_tracking._context import debug_taint_map
 from ddtrace.appsec._iast._taint_tracking._native.taint_tracking import VulnerabilityType
 from ddtrace.appsec._iast._taint_tracking._native.taint_tracking import is_notinterned_notfasttainted_unicode
 from ddtrace.appsec._iast._taint_tracking._native.taint_tracking import set_fast_tainted_if_notinterned_unicode
 from ddtrace.appsec._iast._taint_tracking._taint_objects import taint_pyobject
+from ddtrace.appsec._iast._taint_tracking._taint_objects import taint_pyobject_with_ranges
 from ddtrace.appsec._iast._taint_tracking._taint_objects_base import is_pyobject_tainted
 from ddtrace.appsec._iast._taint_tracking.aspects import add_aspect
 from ddtrace.appsec._iast._taint_tracking.aspects import bytearray_extend_aspect as extend_aspect
 from ddtrace.appsec._iast._taint_tracking.aspects import format_aspect
 from ddtrace.appsec._iast._taint_tracking.aspects import join_aspect
 from tests.appsec.iast.iast_utils import IAST_VALID_LOG
-from tests.utils import override_global_config
+from tests.appsec.iast.iast_utils import _end_iast_context_and_oce
+from tests.appsec.iast.iast_utils import _start_iast_context_and_oce
 
 
 def test_source_origin_refcount():
@@ -155,7 +153,7 @@ def test_collisions_str():
     for n in mixed_nottainted:
         assert len(get_ranges(n)) == 0, f"id {id(n)} in {(id(n) in mixed_tainted_ids)}"
 
-    taint_map = literal_eval(debug_taint_map())
+    taint_map = literal_eval(debug_taint_map(_get_iast_context_id()))
     assert taint_map != []
     for i in taint_map:
         assert abs(i["Value"]["Hash"]) > 1000
@@ -224,7 +222,7 @@ def test_collisions_bytes():
     for n in mixed_nottainted:
         assert len(get_ranges(n)) == 0, f"id {id(n)} in {(id(n) in mixed_tainted_ids)}"
 
-    taint_map = literal_eval(debug_taint_map())
+    taint_map = literal_eval(debug_taint_map(_get_iast_context_id()))
     assert taint_map != []
     for i in taint_map:
         assert abs(i["Value"]["Hash"]) > 1000
@@ -299,7 +297,7 @@ def test_collisions_bytearray():
     for n in mixed_nottainted:
         assert len(get_ranges(n)) == 0, f"id {id(n)} in {(id(n) in mixed_tainted_ids)}"
 
-    taint_map = literal_eval(debug_taint_map())
+    taint_map = literal_eval(debug_taint_map(_get_iast_context_id()))
     assert taint_map != []
     for i in taint_map:
         assert abs(i["Value"]["Hash"]) > 1000
@@ -308,7 +306,8 @@ def test_collisions_bytearray():
 def test_set_get_ranges_str():
     s1 = "abcde😁"
     s2 = "defg"
-    set_ranges(s1, [_RANGE1, _RANGE2])
+    assert taint_pyobject_with_ranges(s1, [_RANGE1, _RANGE2])
+    assert is_pyobject_tainted(s1)
     assert get_ranges(s1) == [_RANGE1, _RANGE2]
     assert not get_ranges(s2)
 
@@ -316,25 +315,17 @@ def test_set_get_ranges_str():
 def test_set_get_ranges_other():
     s1 = 12345
     s2 = None
-    set_ranges(s1, [_RANGE1, _RANGE2])
-    set_ranges(s2, [_RANGE1, _RANGE2])
-    with pytest.raises(
-        ValueError,
-        match=re.escape("iast::propagation::native::error::Get ranges error: Invalid type of candidate_text variable"),
-    ):
-        get_ranges(s1)
+    assert set_ranges(s1, [_RANGE1, _RANGE2], _get_iast_context_id()) is False
+    assert set_ranges(s2, [_RANGE1, _RANGE2], _get_iast_context_id()) is False
 
-    with pytest.raises(
-        ValueError,
-        match=re.escape("iast::propagation::native::error::Get ranges error: Invalid type of candidate_text variable"),
-    ):
-        get_ranges(s2)
+    assert get_ranges(s1) == []
+    assert get_ranges(s2) == []
 
 
 def test_set_get_ranges_bytes():
     b1 = b"ABCDE"
     b2 = b"DEFG"
-    set_ranges(b1, [_RANGE2, _RANGE1])
+    assert taint_pyobject_with_ranges(b1, [_RANGE2, _RANGE1])
     assert get_ranges(b1) == [_RANGE2, _RANGE1]
     assert not get_ranges(b2) == [_RANGE2, _RANGE1]
 
@@ -342,7 +333,7 @@ def test_set_get_ranges_bytes():
 def test_set_get_ranges_bytearray():
     b1 = bytearray(b"abcdef")
     b2 = bytearray(b"abcdef")
-    set_ranges(b1, [_RANGE1, _RANGE2])
+    assert taint_pyobject_with_ranges(b1, [_RANGE1, _RANGE2])
     assert get_ranges(b1) == [_RANGE1, _RANGE2]
     assert not get_ranges(b2) == [_RANGE1, _RANGE2]
 
@@ -427,7 +418,7 @@ def test_shift_taint_ranges(source, vulnerability_type):
 
 
 def test_are_all_text_all_ranges():
-    s1 = "abcdef"
+    s1 = "abc123"
     s2 = "ghijk"
     s3 = "xyzv"
     num = 123456
@@ -435,9 +426,27 @@ def test_are_all_text_all_ranges():
     source4 = Source(name="name4", value="value4", origin=OriginType.COOKIE)
     range3 = TaintRange(2, 3, source3)
     range4 = TaintRange(4, 5, source4)
-    set_ranges(s1, [_RANGE1, _RANGE2])
-    set_ranges(s2, [range3, _RANGE2])
-    set_ranges(s3, [range4, _RANGE1])
+    assert _num_objects_tainted_in_request() == 0
+
+    a_1 = taint_pyobject(
+        "abc1234",
+        source_name="test_num_objects_tainted",
+        source_value="abc1234",
+        source_origin=OriginType.PARAMETER,
+    )
+    assert is_pyobject_tainted(a_1)
+
+    assert set_ranges(s1, [_RANGE1, _RANGE2], _get_iast_context_id())
+    assert _num_objects_tainted_in_request() == 2
+    assert is_pyobject_tainted(s1)
+
+    assert set_ranges(s2, [range3, _RANGE2], _get_iast_context_id())
+    assert _num_objects_tainted_in_request() == 3
+    assert is_pyobject_tainted(s2)
+
+    assert set_ranges(s3, [range4, _RANGE1], _get_iast_context_id())
+    assert _num_objects_tainted_in_request() == 4
+
     all_ranges, candidate_ranges = are_all_text_all_ranges(s1, (s2, s3, num))
     # Ranges are inserted at the start except the candidate ones that are appended
     assert all_ranges == [range3, _RANGE2, range4, _RANGE1, _RANGE1, _RANGE2]
@@ -456,11 +465,11 @@ def test_get_range_by_hash():
 
 
 def test_num_objects_tainted():
-    create_context()
+    _start_iast_context_and_oce()
     a_1 = "abc123_len1"
     a_2 = "def456__len2"
     a_3 = "ghi789___len3"
-    assert num_objects_tainted() == 0
+    assert _num_objects_tainted_in_request() == 0
     a_1 = taint_pyobject(
         a_1,
         source_name="test_num_objects_tainted",
@@ -479,43 +488,42 @@ def test_num_objects_tainted():
         source_value=a_3,
         source_origin=OriginType.PARAMETER,
     )
-    assert num_objects_tainted() == 3
+    assert _num_objects_tainted_in_request() == 3
 
 
 def test_reset_objects():
-    create_context()
-
     a_1 = "abc123"
     a_2 = "def456"
-    assert num_objects_tainted() == 0
+    assert _num_objects_tainted_in_request() == 0
     a_1 = taint_pyobject(
         a_1,
         source_name="test_num_objects_tainted",
         source_value=a_1,
         source_origin=OriginType.PARAMETER,
     )
-    assert num_objects_tainted() == 1
+    assert _num_objects_tainted_in_request() == 1
 
-    reset_context()
-    create_context()
+    _end_iast_context_and_oce()
+    _start_iast_context_and_oce()
     a_2 = taint_pyobject(
         a_2,
         source_name="test_num_objects_tainted",
         source_value=a_2,
         source_origin=OriginType.PARAMETER,
     )
-    assert num_objects_tainted() == 1
+    assert _num_objects_tainted_in_request() == 1
 
-    reset_context()
-    create_context()
+    _end_iast_context_and_oce()
+    _start_iast_context_and_oce()
 
-    assert num_objects_tainted() == 0
+    assert _num_objects_tainted_in_request() == 0
 
-    reset_context()
+    _end_iast_context_and_oce()
 
 
 def context_loop():
     a_1 = "abc123"
+    assert _get_iast_context_id() is None
     for i in range(25):
         a_1 = taint_pyobject(
             a_1,
@@ -524,27 +532,40 @@ def context_loop():
             source_origin=OriginType.PARAMETER,
         )
         sleep(0.01)
-    assert is_pyobject_tainted(a_1), "Tainting lost"
+    return is_pyobject_tainted(a_1)
 
 
 def reset_contexts_loop():
-    create_context()
+    context_result = _start_iast_context_and_oce()
 
-    a_1 = "abc123"
-    for i in range(25):
-        a_1 = taint_pyobject(
-            a_1,
-            source_name="test_num_objects_tainted",
-            source_value=a_1,
-            source_origin=OriginType.PARAMETER,
-        )
-        sleep(0.01)
-    reset_contexts()
+    if context_result is not None:
+        a_1 = "abc123"
+        for i in range(25):
+            a_1 = taint_pyobject(
+                a_1,
+                source_name="test_num_objects_tainted",
+                source_value=a_1,
+                source_origin=OriginType.PARAMETER,
+            )
+            sleep(0.01)
+        context_result = _end_iast_context_and_oce()
+
+    return context_result is not None
 
 
 async def async_context_loop(task_id: int):
     await asyncio.sleep(0.03)
-    return context_loop()
+    a_1 = "abc123"
+    assert _get_iast_context_id() >= 0
+    for i in range(25):
+        a_1 = taint_pyobject(
+            a_1,
+            source_name="test_num_objects_tainted",
+            source_value=a_1,
+            source_origin=OriginType.PARAMETER,
+        )
+        sleep(0.01)
+    return is_pyobject_tainted(a_1)
 
 
 async def async_reset_contexts_loop(task_id: int):
@@ -552,56 +573,59 @@ async def async_reset_contexts_loop(task_id: int):
     return reset_contexts_loop()
 
 
-def test_race_conditions_threads(caplog, telemetry_writer):
-    """we want to validate context is working correctly among multiple request and no race condition creating and
-    destroying contexts
+def test_contexts_in_threads(caplog, telemetry_writer):
+    """Validate thread-local context behavior with ContextVar-based context_id.
+
+    Each ThreadPool worker has its own IAST context_id stored in a ContextVar,
+    so context_ids are not shared across threads. This test ensures multiple
+    concurrent requests do not race when creating/finishing contexts and that
+    per-thread isolation is preserved.
     """
     pool = ThreadPool(processes=3)
     results_async = [pool.apply_async(context_loop) for _ in range(20)]
-    _ = [res.get() for res in results_async]
+    results = [res.get() for res in results_async]
+    assert results.count(True) == 0
 
     log_messages = [record.message for record in caplog.get_records("call")]
     for message in log_messages:
         if IAST_VALID_LOG.search(message):
             pytest.fail(message)
 
+    list_metrics_logs = [
+        log for log in telemetry_writer._logs if not log["message"].startswith("failed to send, dropping")
+    ]
+    assert len(list_metrics_logs) == 0
+
+
+def test_context_race_conditions_threads(caplog, telemetry_writer):
+    """we want to validate context is working correctly among multiple request and no race condition creating and
+    destroying contexts
+    """
+    _end_iast_context_and_oce()
+    pool = ThreadPool(processes=3)
+    results_async = [pool.apply_async(reset_contexts_loop) for _ in range(20)]
+    results = [res.get() for res in results_async]
+    assert results.count(True) <= 2
+    log_messages = [record.message for record in caplog.get_records("call")]
+    assert len([message for message in log_messages if IAST_VALID_LOG.search(message)]) == 0
     list_metrics_logs = list(telemetry_writer._logs)
     assert len(list_metrics_logs) == 0
 
 
-@pytest.mark.skip_iast_check_logs
-def test_race_conditions_reset_contexts_async(caplog, telemetry_writer):
-    """we want to validate context is working correctly among multiple request and no race condition creating and
-    destroying contexts
-    """
-    with override_global_config(dict(_iast_debug=True)), caplog.at_level(logging.DEBUG):
-        pool = ThreadPool(processes=3)
-        results_async = [pool.apply_async(reset_contexts_loop) for _ in range(20)]
-        _ = [res.get() for res in results_async]
-
-        log_messages = [record.message for record in caplog.get_records("call")]
-        if not any(IAST_VALID_LOG.search(message) for message in log_messages):
-            pytest.fail("All contexts reset but no fail")
-        list_metrics_logs = list(telemetry_writer._logs)
-        assert len(list_metrics_logs) == 0
-
-
 @pytest.mark.asyncio
-async def test_race_conditions_reset_contex_async(caplog, telemetry_writer):
+async def test_context_race_conditions_async(caplog, telemetry_writer):
     """we want to validate context is working correctly among multiple request and no race condition creating and
     destroying contexts
     """
     tasks = [async_context_loop(i) for i in range(7)]
 
     results = await asyncio.gather(*tasks)
-    assert results
-
+    assert results.count(True) == 7
     log_messages = [record.message for record in caplog.get_records("call")]
-    for message in log_messages:
-        if IAST_VALID_LOG.search(message):
-            pytest.fail(message)
-
-    list_metrics_logs = list(telemetry_writer._logs)
+    assert len([message for message in log_messages if IAST_VALID_LOG.search(message)]) == 0
+    list_metrics_logs = [
+        log for log in telemetry_writer._logs if not log["message"].startswith("failed to send, dropping")
+    ]
     assert len(list_metrics_logs) == 0
 
 
