@@ -6,6 +6,7 @@ import pytest
 from ddtrace.appsec._constants import IAST
 from ddtrace.appsec._constants import IAST_SPAN_TAGS
 from ddtrace.appsec._constants import STACK_TRACE
+from ddtrace.appsec._iast import oce
 from ddtrace.appsec._iast._patch_modules import _apply_custom_security_controls
 from ddtrace.appsec._iast._patch_modules import _testing_unpatch_iast
 from ddtrace.appsec._iast.constants import VULN_CMDI
@@ -16,8 +17,6 @@ from ddtrace.appsec._iast.constants import VULN_SSRF
 from ddtrace.appsec._iast.constants import VULN_STACKTRACE_LEAK
 from ddtrace.appsec._iast.constants import VULN_UNVALIDATED_REDIRECT
 from ddtrace.settings.asm import config as asm_config
-from tests.appsec.iast.iast_utils import _end_iast_context_and_oce
-from tests.appsec.iast.iast_utils import _start_iast_context_and_oce
 from tests.appsec.iast.iast_utils import get_line_and_hash
 from tests.appsec.iast.iast_utils import load_iast_report
 from tests.appsec.integrations.django_tests.utils import _aux_appsec_get_root_span
@@ -154,22 +153,21 @@ def test_django_view_with_exception(client, iast_span, tracer, payload, content_
 
 
 @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
-def test_django_tainted_user_agent_iast_disabled(client, iast_span, tracer):
-    with override_global_config(dict(_iast_enabled=False, _iast_deduplication_enabled=False)):
-        root_span, response = _aux_appsec_get_root_span(
-            client,
-            iast_span,
-            tracer,
-            payload=urlencode({"mytestingbody_key": "mytestingbody_value"}),
-            content_type="application/x-www-form-urlencoded",
-            url="/appsec/taint-checking-disabled/?q=aaa",
-            headers={"HTTP_USER_AGENT": "test/1.2.3"},
-        )
+def test_django_tainted_user_agent_iast_disabled(client, iast_span_disabled, tracer):
+    root_span, response = _aux_appsec_get_root_span(
+        client,
+        iast_span_disabled,
+        tracer,
+        payload=urlencode({"mytestingbody_key": "mytestingbody_value"}),
+        content_type="application/x-www-form-urlencoded",
+        url="/appsec/taint-checking-disabled/?q=aaa",
+        headers={"HTTP_USER_AGENT": "test/1.2.3"},
+    )
 
-        assert load_iast_report(root_span) is None
+    assert load_iast_report(root_span) is None
 
-        assert response.status_code == 200
-        assert response.content == b"test/1.2.3"
+    assert response.status_code == 200
+    assert response.content == b"test/1.2.3"
 
 
 @pytest.mark.django_db()
@@ -207,7 +205,9 @@ def test_django_sqli_http_request_parameter_metrics_disabled(client, iast_spans_
         url="/appsec/sqli_http_request_parameter_name_post/",
         headers={"HTTP_USER_AGENT": "test/1.2.3"},
     )
-    assert root_span.get_metric(IAST.ENABLED) == 0.0
+    assert (
+        root_span.get_metric(IAST.ENABLED) == 0.0
+    ), f"IAST should be disabled. Metric: {root_span.get_metric(IAST.ENABLED)}"
     assert root_span.get_metric(IAST_SPAN_TAGS.TELEMETRY_REQUEST_TAINTED) is None
     assert root_span.get_metric(IAST_SPAN_TAGS.TELEMETRY_EXECUTED_SINK + ".sql_injection") is None
     assert root_span.get_metric(IAST_SPAN_TAGS.TELEMETRY_EXECUTED_SINK + ".header_injection") is None
@@ -268,6 +268,131 @@ def test_django_sqli_http_request_parameter(client, iast_span, tracer):
     assert loaded["vulnerabilities"][0]["hash"] == hash_value
 
 
+@pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
+def test_django_untrusted_serialization_yaml(client, iast_span, tracer):
+    root_span, response = _aux_appsec_get_root_span(
+        client,
+        iast_span,
+        tracer,
+        url="/iast/untrusted/yaml/?input=a: 1",
+    )
+
+    vuln_type = "UNTRUSTED_SERIALIZATION"
+
+    assert response.status_code == 200
+
+    loaded = load_iast_report(root_span)
+
+    line, hash_value = get_line_and_hash("untrusted_serialization_yaml_view", vuln_type, filename=TEST_FILE)
+
+    assert loaded["sources"] == [
+        {
+            "name": "input",
+            "origin": "http.request.parameter",
+            "value": "a: 1",
+        }
+    ]
+
+    assert loaded["vulnerabilities"][0]["type"] == vuln_type
+    assert loaded["vulnerabilities"][0]["location"]["path"] == TEST_FILE
+    assert loaded["vulnerabilities"][0]["location"]["line"] == line
+    assert loaded["vulnerabilities"][0]["hash"] == hash_value
+
+
+@pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
+def test_django_untrusted_serialization_yaml_load(client, iast_span, tracer):
+    root_span, response = _aux_appsec_get_root_span(
+        client,
+        iast_span,
+        tracer,
+        url="/iast/untrusted/yaml/load/?input=a: 1",
+    )
+
+    vuln_type = "UNTRUSTED_SERIALIZATION"
+
+    assert response.status_code == 200
+
+    loaded = load_iast_report(root_span)
+
+    line, hash_value = get_line_and_hash("untrusted_serialization_yaml_load", vuln_type, filename=TEST_FILE)
+
+    assert loaded["sources"] == [
+        {
+            "name": "input",
+            "origin": "http.request.parameter",
+            "value": "a: 1",
+        }
+    ]
+
+    assert loaded["vulnerabilities"][0]["type"] == vuln_type
+    assert loaded["vulnerabilities"][0]["location"]["path"] == TEST_FILE
+    assert loaded["vulnerabilities"][0]["location"]["line"] == line
+    assert loaded["vulnerabilities"][0]["hash"] == hash_value
+
+
+@pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
+def test_django_untrusted_serialization_yaml_safe_load(client, iast_span, tracer):
+    root_span, response = _aux_appsec_get_root_span(
+        client,
+        iast_span,
+        tracer,
+        url="/iast/untrusted/yaml/safe_load/?input=a: 1",
+    )
+
+    assert response.status_code == 200
+
+    loaded = load_iast_report(root_span)
+    # safe_load should not be reported as untrusted serialization
+    assert loaded is None
+
+
+@pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
+def test_django_untrusted_serialization_pickle_smoke(client, iast_span, tracer):
+    root_span, response = _aux_appsec_get_root_span(
+        client,
+        iast_span,
+        tracer,
+        url="/iast/untrusted/pickle/?input=AQID",
+    )
+
+    vuln_type = "UNTRUSTED_SERIALIZATION"
+
+    assert response.status_code == 200
+    loaded = load_iast_report(root_span)
+
+    line, hash_value = get_line_and_hash("untrusted_serialization_pickle", vuln_type, filename=TEST_FILE)
+    assert loaded["sources"] == []
+
+    assert loaded["vulnerabilities"][0]["type"] == vuln_type
+    assert loaded["vulnerabilities"][0]["location"]["path"] == TEST_FILE
+    assert loaded["vulnerabilities"][0]["location"]["line"] == line
+    assert loaded["vulnerabilities"][0]["hash"] == hash_value
+
+
+@pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
+def test_django_untrusted_serialization_dill_smoke(client, iast_span, tracer):
+    root_span, response = _aux_appsec_get_root_span(
+        client,
+        iast_span,
+        tracer,
+        url="/iast/untrusted/dill/?input=AQID",
+    )
+
+    vuln_type = "UNTRUSTED_SERIALIZATION"
+
+    assert response.status_code == 200
+
+    loaded = load_iast_report(root_span)
+
+    line, hash_value = get_line_and_hash("untrusted_serialization_dill", vuln_type, filename=TEST_FILE)
+    assert loaded["sources"] == []
+
+    assert loaded["vulnerabilities"][0]["type"] == vuln_type
+    assert loaded["vulnerabilities"][0]["location"]["path"] == TEST_FILE
+    assert loaded["vulnerabilities"][0]["location"]["line"] == line
+    assert loaded["vulnerabilities"][0]["hash"] == hash_value
+
+
 @pytest.mark.django_db()
 @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
 def test_django_sqli_http_request_parameter_name_get_and_stacktrace(client, iast_span, tracer):
@@ -985,9 +1110,9 @@ def test_django_command_injection_security_control(client, tracer, security_cont
             _iast_security_controls=security_control,
         )
     ):
+        oce.reconfigure()
         _apply_custom_security_controls().patch()
         span = TracerSpanContainer(tracer)
-        _start_iast_context_and_oce()
         root_span, _ = _aux_appsec_get_root_span(
             client,
             span,
@@ -1003,7 +1128,6 @@ def test_django_command_injection_security_control(client, tracer, security_cont
             assert root_span.get_metric(IAST_SPAN_TAGS.TELEMETRY_SUPPRESSED_VULNERABILITY + ".command_injection")
         else:
             assert loaded is not None
-        _end_iast_context_and_oce()
         span.reset()
         _testing_unpatch_iast()
 
@@ -1447,6 +1571,29 @@ def test_django_xss_secure(client, iast_span, tracer):
 
 
 def test_django_ospathjoin_propagation(client, iast_span, tracer):
+    """Validate taint propagation for os.path.join with str, Path and PosixPath.
+
+    The Django view at `ospathjoin_propagation` returns three boolean flags in
+    the body after "OK:", corresponding to whether the result of the following
+    joins is tainted:
+
+    1) os.path.join(str, str)
+    2) os.path.join(Path, Path)
+    3) os.path.join(PosixPath, PosixPath)
+
+    The first case (str + str) is expected to propagate taint consistently, so
+    this test asserts that the response starts with "OK:True:".
+
+    The behavior for `pathlib.Path` and `pathlib.PosixPath` can differ across
+    Python versions because CPython has evolved the implementation of
+    `pathlib` (e.g., `joinpath`, `__fspath__`, and how it interacts with
+    `os.path.join`). Our IAST instrumentation hooks may be exercised through
+    different code paths depending on the stdlib version, which can lead to
+    varying taint propagation outcomes for these pathlib types. To keep the test
+    stable across versions, we avoid asserting the exact values of the second
+    and third flags; instead we only verify the prefix and that no IAST report
+    is emitted for this endpoint.
+    """
     root_span, response = _aux_appsec_get_root_span(
         client,
         iast_span,
@@ -1455,7 +1602,7 @@ def test_django_ospathjoin_propagation(client, iast_span, tracer):
     )
 
     assert response.status_code == 200
-    assert response.content == b"OK:True:False:False", response.content
+    assert response.content.startswith(b"OK:True:"), response.content
 
     loaded = load_iast_report(root_span)
     assert loaded is None
@@ -1499,9 +1646,10 @@ def test_django_iast_sampling_2(client, test_spans_2_vuln_per_request_deduplicat
         assert response.status_code == 200
         assert str(response.content, encoding="utf-8") == f"OK:value{i}", response.content
         if i > 0:
-            assert load_iast_report(root_span) is None
+            assert load_iast_report(root_span) is None, f"IAST is NOT none for request {i}"
         else:
             loaded = load_iast_report(root_span)
+            assert loaded, f"IAST is none for request {i}"
             assert len(loaded["vulnerabilities"]) == 2
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "param", "redacted": True, "pattern": "abcdef"}
@@ -1525,10 +1673,11 @@ def test_django_iast_sampling_by_route_method(client, test_spans_2_vuln_per_requ
         assert response.status_code == 200
         assert str(response.content, encoding="utf-8") == f"OK:value{i}:{i}", response.content
         if i > 7:
-            assert load_iast_report(root_span) is None
+            assert load_iast_report(root_span) is None, f"IAST is none for request {i}"
         else:
             loaded = load_iast_report(root_span)
-            assert len(loaded["vulnerabilities"]) == 2
+            num_vulns = len(loaded["vulnerabilities"])
+            assert num_vulns == 2, f"IAST has {num_vulns} vulnerabilities for request {i}"
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "param", "redacted": True, "pattern": "abcdef"}
             ]
