@@ -9,7 +9,7 @@ import uuid
 
 import pytest
 
-from tests.appsec.appsec_utils import gunicorn_server
+from tests.appsec.appsec_utils import gunicorn_flask_server
 from tests.appsec.integrations.flask_tests.utils import _PORT
 from tests.appsec.integrations.flask_tests.utils import _multi_requests
 from tests.appsec.integrations.flask_tests.utils import _request_200
@@ -179,7 +179,7 @@ def _request_403(client, debug_mode=False, max_retries=40, sleep_time=1):
 
 def test_load_testing_appsec_ip_blocking_gunicorn_rc_disabled():
     token = "test_load_testing_appsec_ip_blocking_gunicorn_rc_disabled_{}".format(str(uuid.uuid4()))
-    with gunicorn_server(remote_configuration_enabled="false", token=token, port=_PORT) as context:
+    with gunicorn_flask_server(remote_configuration_enabled="false", token=token, port=_PORT) as context:
         _, gunicorn_client, pid = context
 
         _request_200(gunicorn_client)
@@ -193,7 +193,7 @@ def test_load_testing_appsec_ip_blocking_gunicorn_rc_disabled():
 
 def test_load_testing_appsec_ip_blocking_gunicorn_block():
     token = "test_load_testing_appsec_ip_blocking_gunicorn_block_{}".format(str(uuid.uuid4()))
-    with gunicorn_server(token=token, port=_PORT, use_ddtrace_cmd=False) as context:
+    with gunicorn_flask_server(token=token, port=_PORT, use_ddtrace_cmd=False) as context:
         _, gunicorn_client, pid = context
 
         _request_200(gunicorn_client)
@@ -209,7 +209,7 @@ def test_load_testing_appsec_ip_blocking_gunicorn_block():
 
 def test_load_testing_appsec_ip_blocking_gunicorn_block_and_kill_child_worker():
     token = "test_load_testing_appsec_ip_blocking_gunicorn_block_and_kill_child_worker_{}".format(str(uuid.uuid4()))
-    with gunicorn_server(token=token, port=_PORT, use_ddtrace_cmd=False) as context:
+    with gunicorn_flask_server(token=token, port=_PORT, use_ddtrace_cmd=False) as context:
         _, gunicorn_client, pid = context
 
         _request_200(gunicorn_client)
@@ -233,7 +233,7 @@ def test_load_testing_appsec_1click_and_ip_blocking_gunicorn_block_and_kill_chil
     token = "test_load_testing_appsec_1click_and_ip_blocking_gunicorn_block_and_kill_child_worker_{}".format(
         str(uuid.uuid4())
     )
-    with gunicorn_server(appsec_enabled="", token=token, port=_PORT) as context:
+    with gunicorn_flask_server(appsec_enabled="", token=token, port=_PORT) as context:
         _, gunicorn_client, pid = context
 
         _request_200(gunicorn_client, debug_mode=False)
