@@ -1,5 +1,7 @@
 from contextlib import contextmanager
+from http.client import RemoteDisconnected
 import json
+import socket
 from unittest import mock
 
 import pytest
@@ -11,10 +13,10 @@ from ddtrace.internal.ci_visibility._api_client import AgentlessTestVisibilityAP
 from ddtrace.internal.ci_visibility._api_client import EVPProxyTestVisibilityAPIClient
 from ddtrace.internal.ci_visibility._api_client import ITRData
 from ddtrace.internal.ci_visibility._api_client import TestVisibilityAPISettings
-from ddtrace.internal.ci_visibility.constants import EVP_PROXY_AGENT_BASE_PATH
-from ddtrace.internal.ci_visibility.constants import EVP_PROXY_AGENT_BASE_PATH_V4
 from ddtrace.internal.ci_visibility.constants import REQUESTS_MODE
 from ddtrace.internal.ci_visibility.git_data import GitData
+from ddtrace.internal.evp_proxy.constants import EVP_PROXY_AGENT_BASE_PATH
+from ddtrace.internal.evp_proxy.constants import EVP_PROXY_AGENT_BASE_PATH_V4
 from ddtrace.settings._config import Config
 from tests.ci_visibility.api_client._util import _AGENTLESS
 from tests.ci_visibility.api_client._util import _EVP_PROXY
@@ -222,6 +224,68 @@ class TestTestVisibilityAPIClient(TestTestVisibilityAPIClientBase):
                 itr_skipping_level, git_data=git_data, dd_service=dd_service, dd_env=dd_env
             )
 
+    def test_civisibility_api_client_settings_retry_on_errors(self):
+        """Tests that the API call to the settings endpoint is retried in case of server errors."""
+        client = self._get_test_client(
+            itr_skipping_level=ITR_SKIPPING_LEVEL.TEST,
+            api_key="my_api_key",
+            dd_service=None,
+            dd_env=None,
+            git_data=self.git_data_parameters[0],
+        )
+        with mock.patch.object(
+            client,
+            "_do_request",
+            side_effect=[
+                _get_setting_api_response(status_code=500),
+                TimeoutError(),
+                _get_setting_api_response(),
+            ],
+        ) as mock_do_request:
+            with mock.patch("ddtrace.internal.ci_visibility.utils.sleep"):
+                settings = client.fetch_settings(read_from_cache=False)
+
+        assert settings == TestVisibilityAPISettings()
+
+        assert mock_do_request.call_count == 3
+        for call_args, _ in mock_do_request.call_args_list:
+            assert call_args[0] == "POST"
+            assert json.loads(call_args[2]) == self._get_expected_do_request_setting_payload(
+                ITR_SKIPPING_LEVEL.TEST, git_data=self.git_data_parameters[0], dd_service=None, dd_env=None
+            )
+
+    def test_civisibility_api_client_settings_fail_after_5_retries(self):
+        """Tests that the API call to the settings endpoint is retried in case of server errors."""
+        client = self._get_test_client(
+            itr_skipping_level=ITR_SKIPPING_LEVEL.TEST,
+            api_key="my_api_key",
+            dd_service=None,
+            dd_env=None,
+            git_data=self.git_data_parameters[0],
+        )
+        with mock.patch.object(
+            client,
+            "_do_request",
+            side_effect=[
+                _get_setting_api_response(status_code=500),
+                _get_setting_api_response(status_code=504),
+                TimeoutError(),
+                RemoteDisconnected(),
+                socket.timeout(),
+                _get_setting_api_response(),
+            ],
+        ) as mock_do_request:
+            with mock.patch("ddtrace.internal.ci_visibility.utils.sleep"):
+                with pytest.raises(socket.timeout):  # raises the last exception
+                    _ = client.fetch_settings(read_from_cache=False)
+
+        assert mock_do_request.call_count == 5
+        for call_args, _ in mock_do_request.call_args_list:
+            assert call_args[0] == "POST"
+            assert json.loads(call_args[2]) == self._get_expected_do_request_setting_payload(
+                ITR_SKIPPING_LEVEL.TEST, git_data=self.git_data_parameters[0], dd_service=None, dd_env=None
+            )
+
     @pytest.mark.parametrize("client_timeout", [None, 5])
     @pytest.mark.parametrize("request_timeout", [None, 10])
     @pytest.mark.parametrize(
