@@ -2,6 +2,7 @@ import os
 
 from opentracing.scope_managers.asyncio import AsyncioScopeManager
 import pytest
+import pytest_asyncio
 
 from ddtrace._trace.sampler import RateSampler
 from ddtrace.constants import _SAMPLING_PRIORITY_KEY
@@ -12,6 +13,7 @@ from ddtrace.contrib.internal.aiohttp.middlewares import CONFIG_KEY
 from ddtrace.contrib.internal.aiohttp.middlewares import trace_app
 from ddtrace.contrib.internal.aiohttp.middlewares import trace_middleware
 from ddtrace.ext import http
+from ddtrace.internal.utils.version import parse_version
 from tests.opentracer.utils import init_tracer
 from tests.tracer.utils_inferred_spans.test_helpers import assert_web_and_inferred_aws_api_gateway_span_data
 from tests.utils import assert_span_http_status_code
@@ -21,6 +23,9 @@ from .app.web import noop_middleware
 from .app.web import setup_app
 
 
+PYTEST_ASYNCIO_VERSION = parse_version(pytest_asyncio.__version__)
+
+
 async def test_handler(app_tracer, aiohttp_client):
     app, tracer = app_tracer
     client = await aiohttp_client(app)
@@ -48,6 +53,7 @@ async def test_handler(app_tracer, aiohttp_client):
     assert span.get_tag("span.kind") == "server"
 
 
+@pytest.mark.skipif(PYTEST_ASYNCIO_VERSION >= (1, 0), reason="'loop' fixture removed")
 @pytest.mark.parametrize("schema_version", [None, "v0", "v1"])
 def test_service_operation_schema(ddtrace_run_python_code_in_subprocess, schema_version):
     """
@@ -113,7 +119,7 @@ if __name__ == "__main__":
         ("foo=bar&foo=baz&x=y", True),
     ),
 )
-async def test_param_handler(app_tracer, aiohttp_client, loop, query_string, trace_query_string):
+async def test_param_handler(app_tracer, aiohttp_client, query_string, trace_query_string):
     app, tracer = app_tracer
     if trace_query_string:
         app[CONFIG_KEY]["trace_query_string"] = True
@@ -262,7 +268,7 @@ async def test_coroutine_chaining(app_tracer, aiohttp_client):
     assert root.get_tag("span.kind") == "server"
 
 
-async def test_static_handler(app_tracer, aiohttp_client, loop):
+async def test_static_handler(app_tracer, aiohttp_client):
     app, tracer = app_tracer
     client = await aiohttp_client(app)
     # it should create a trace with multiple spans
