@@ -86,6 +86,10 @@ MIDDLEWARE = [
     "tests.contrib.django.middleware.EverythingMiddleware",
 ]
 
+if os.getenv("TEST_INCLUDE_ASYNC_ONLY_MIDDLEWARE") == "1":
+    # DEV: Add to the front, since adding at the end causes it to not get called?
+    MIDDLEWARE = ["tests.contrib.django.middleware.async_only_middleware"] + MIDDLEWARE
+
 INSTALLED_APPS = [
     "django.contrib.admin",
     "django.contrib.auth",
