@@ -414,7 +414,6 @@ def test_llmobs_chain(langchain_core, langchain_openai, openai_url, llmobs_event
                 {"content": "{input}", "role": "user"},
             ],
             "variables": {"input": "Can you explain what an LLM chain is?"},
-            "version": "0.0.0",
             "_dd_context_variable_keys": ["context"],
             "_dd_query_variable_keys": ["question"],
         },
@@ -456,7 +455,6 @@ def test_llmobs_chain_nested(langchain_core, langchain_openai, openai_url, llmob
             "id": "langchain.unknown_prompt_template",
             "chat_template": [{"content": "what is the city {person} is from?", "role": "user"}],
             "variables": {"person": "Spongebob Squarepants", "language": "Spanish"},
-            "version": "0.0.0",
             "_dd_context_variable_keys": ["context"],
             "_dd_query_variable_keys": ["question"],
         },
@@ -469,7 +467,6 @@ def test_llmobs_chain_nested(langchain_core, langchain_openai, openai_url, llmob
             "id": "test_langchain_llmobs.prompt2",
             "chat_template": [{"content": "what country is the city {city} in? respond in {language}", "role": "user"}],
             "variables": {"city": mock.ANY, "language": "Spanish"},
-            "version": "0.0.0",
             "_dd_context_variable_keys": ["context"],
             "_dd_query_variable_keys": ["question"],
         },
@@ -505,7 +502,6 @@ def test_llmobs_chain_batch(langchain_core, langchain_openai, llmobs_events, tra
                 "id": "langchain.unknown_prompt_template",
                 "chat_template": [{"content": "Tell me a short joke about {topic}", "role": "user"}],
                 "variables": {"topic": "chickens"},
-                "version": "0.0.0",
                 "_dd_context_variable_keys": ["context"],
                 "_dd_query_variable_keys": ["question"],
             },
@@ -519,7 +515,6 @@ def test_llmobs_chain_batch(langchain_core, langchain_openai, llmobs_events, tra
                 "id": "langchain.unknown_prompt_template",
                 "chat_template": [{"content": "Tell me a short joke about {topic}", "role": "user"}],
                 "variables": {"topic": "pigs"},
-                "version": "0.0.0",
                 "_dd_context_variable_keys": ["context"],
                 "_dd_query_variable_keys": ["question"],
             },
@@ -534,7 +529,6 @@ def test_llmobs_chain_batch(langchain_core, langchain_openai, llmobs_events, tra
                 "id": "langchain.unknown_prompt_template",
                 "chat_template": [{"content": "Tell me a short joke about {topic}", "role": "user"}],
                 "variables": {"topic": "chickens"},
-                "version": "0.0.0",
                 "_dd_context_variable_keys": ["context"],
                 "_dd_query_variable_keys": ["question"],
             },
@@ -548,7 +542,6 @@ def test_llmobs_chain_batch(langchain_core, langchain_openai, llmobs_events, tra
                 "id": "langchain.unknown_prompt_template",
                 "chat_template": [{"content": "Tell me a short joke about {topic}", "role": "user"}],
                 "variables": {"topic": "pigs"},
-                "version": "0.0.0",
                 "_dd_context_variable_keys": ["context"],
                 "_dd_query_variable_keys": ["question"],
             },
@@ -847,6 +840,11 @@ class TestTraceStructureWithLLMIntegrations(SubprocessTestCase):
         DD_API_KEY="<not-a-real-key>",
     )
 
+    azure_openai_env_config = dict(
+        OPENAI_API_VERSION="2024-12-01-preview",
+        AZURE_OPENAI_API_KEY=os.getenv("AZURE_OPENAI_API_KEY", "testing"),
+    )
+
     anthropic_env_config = dict(
         ANTHROPIC_API_KEY=os.getenv("ANTHROPIC_API_KEY", "testing"),
         DD_API_KEY="<not-a-real-key>",
@@ -891,6 +889,11 @@ class TestTraceStructureWithLLMIntegrations(SubprocessTestCase):
         llm = OpenAI(base_url="http://localhost:9126/vcr/openai")
         llm.invoke("Can you explain what Descartes meant by 'I think, therefore I am'?")
 
+    @staticmethod
+    def _call_azure_openai_chat(AzureChatOpenAI):
+        llm = AzureChatOpenAI(azure_endpoint="http://localhost:9126/vcr/azure_openai", deployment_name="gpt-4.1-mini")
+        llm.invoke("Can you explain what Descartes meant by 'I think, therefore I am'?")
+
     @staticmethod
     def _call_openai_embedding(OpenAIEmbeddings):
         embedding = OpenAIEmbeddings(base_url="http://localhost:9126/vcr/openai")
@@ -924,6 +927,15 @@ class TestTraceStructureWithLLMIntegrations(SubprocessTestCase):
         self._call_openai_llm(OpenAI)
         self._assert_trace_structure_from_writer_call_args(["workflow", "llm"])
 
+    @run_in_subprocess(env_overrides=azure_openai_env_config)
+    def test_llmobs_with_openai_enabled_azure(self):
+        from langchain_openai import AzureChatOpenAI
+
+        patch(langchain=True, openai=True)
+        LLMObs.enable(ml_app="<ml-app-name>", integrations_enabled=False)
+        self._call_azure_openai_chat(AzureChatOpenAI)
+        self._assert_trace_structure_from_writer_call_args(["workflow", "llm"])
+
     @run_in_subprocess(env_overrides=openai_env_config)
     def test_llmobs_with_openai_enabled_non_ascii_value(self):
         """Regression test to ensure that non-ascii text values for workflow spans are not encoded."""
@@ -966,6 +978,16 @@ class TestTraceStructureWithLLMIntegrations(SubprocessTestCase):
         self._call_openai_llm(OpenAI)
         self._assert_trace_structure_from_writer_call_args(["llm"])
 
+    @run_in_subprocess(env_overrides=azure_openai_env_config)
+    def test_llmobs_with_openai_disabled_azure(self):
+        from langchain_openai import AzureChatOpenAI
+
+        patch(langchain=True)
+
+        LLMObs.enable(ml_app="<ml-app-name>", integrations_enabled=False)
+        self._call_azure_openai_chat(AzureChatOpenAI)
+        self._assert_trace_structure_from_writer_call_args(["llm"])
+
     @run_in_subprocess(env_overrides=anthropic_env_config)
     def test_llmobs_with_anthropic_enabled(self):
         from langchain_anthropic import ChatAnthropic
