@@ -13,7 +13,6 @@ from tests.utils import override_global_config
 from tests.utils import snapshot_context
 
 
-TIKTOKEN_AVAILABLE = os.getenv("TIKTOKEN_AVAILABLE", False)
 pytestmark = pytest.mark.skipif(
     parse_version(openai_module.version.VERSION) < (1, 0), reason="This module only tests openai >= 1.0"
 )
@@ -35,6 +34,22 @@ def test_model_list(api_key_in_env, request_api_key, openai, openai_vcr, snapsho
             client.models.list()
 
 
+@pytest.mark.parametrize("api_key_in_env", [True, False])
+def test_model_list_pagination(api_key_in_env, request_api_key, openai, openai_vcr, snapshot_tracer):
+    with snapshot_context(
+        token="tests.contrib.openai.test_openai.test_model_list_pagination",
+        ignores=["meta.http.useragent", "meta.openai.api_type", "meta.openai.api_base", "meta.openai.request.user"],
+    ):
+        with openai_vcr.use_cassette("model_list.yaml"):
+            client = openai.OpenAI(api_key=request_api_key)
+            count = 0
+            for model in client.models.list():
+                count += 1
+                if count >= 2:
+                    break
+            assert count >= 2
+
+
 @pytest.mark.parametrize("api_key_in_env", [True, False])
 async def test_model_alist(api_key_in_env, request_api_key, openai, openai_vcr, snapshot_tracer):
     with snapshot_context(
@@ -46,6 +61,22 @@ async def test_model_alist(api_key_in_env, request_api_key, openai, openai_vcr,
             await client.models.list()
 
 
+@pytest.mark.parametrize("api_key_in_env", [True, False])
+async def test_model_alist_pagination(api_key_in_env, request_api_key, openai, openai_vcr, snapshot_tracer):
+    with snapshot_context(
+        token="tests.contrib.openai.test_openai.test_model_alist_pagination",
+        ignores=["meta.http.useragent", "meta.openai.api_type", "meta.openai.api_base", "meta.openai.request.user"],
+    ):
+        with openai_vcr.use_cassette("model_alist.yaml"):
+            client = openai.AsyncOpenAI(api_key=request_api_key)
+            count = 0
+            async for model in client.models.list():
+                count += 1
+                if count >= 2:
+                    break
+            assert count >= 2
+
+
 @pytest.mark.parametrize("api_key_in_env", [True, False])
 def test_model_retrieve(api_key_in_env, request_api_key, openai, openai_vcr, snapshot_tracer):
     with snapshot_context(
@@ -721,51 +752,32 @@ def test_span_finish_on_stream_error(openai, openai_vcr, snapshot_tracer):
             )
 
 
-@pytest.mark.snapshot
-@pytest.mark.skipif(TIKTOKEN_AVAILABLE, reason="This test estimates token counts")
-def test_completion_stream_est_tokens(openai, openai_vcr, snapshot_tracer):
-    with openai_vcr.use_cassette("completion_streamed.yaml"):
-        with mock.patch("ddtrace.contrib.internal.openai.utils.encoding_for_model", create=True) as mock_encoding:
-            mock_encoding.return_value.encode.side_effect = lambda x: [1, 2]
-            client = openai.OpenAI()
-            resp = client.completions.create(model="ada", prompt="Hello world", stream=True, n=None)
-            _ = [c for c in resp]
-
-
-@pytest.mark.skipif(not TIKTOKEN_AVAILABLE, reason="This test computes token counts using tiktoken")
 @pytest.mark.snapshot(token="tests.contrib.openai.test_openai.test_completion_stream")
 def test_completion_stream(openai, openai_vcr, snapshot_tracer):
     with openai_vcr.use_cassette("completion_streamed.yaml"):
-        with mock.patch("ddtrace.contrib.internal.openai.utils.encoding_for_model", create=True) as mock_encoding:
-            mock_encoding.return_value.encode.side_effect = lambda x: [1, 2]
-            client = openai.OpenAI()
-            resp = client.completions.create(model="ada", prompt="Hello world", stream=True, n=None)
-            _ = [c for c in resp]
+        client = openai.OpenAI()
+        resp = client.completions.create(model="ada", prompt="Hello world", stream=True, n=None)
+        _ = [c for c in resp]
 
 
-@pytest.mark.skipif(not TIKTOKEN_AVAILABLE, reason="This test computes token counts using tiktoken")
 @pytest.mark.snapshot(token="tests.contrib.openai.test_openai.test_completion_stream")
 async def test_completion_async_stream(openai, openai_vcr, snapshot_tracer):
     with openai_vcr.use_cassette("completion_streamed.yaml"):
-        with mock.patch("ddtrace.contrib.internal.openai.utils.encoding_for_model", create=True) as mock_encoding:
-            mock_encoding.return_value.encode.side_effect = lambda x: [1, 2]
-            client = openai.AsyncOpenAI()
-            resp = await client.completions.create(model="ada", prompt="Hello world", stream=True, n=None)
-            _ = [c async for c in resp]
+        client = openai.AsyncOpenAI()
+        resp = await client.completions.create(model="ada", prompt="Hello world", stream=True, n=None)
+        _ = [c async for c in resp]
 
 
 @pytest.mark.skipif(
-    parse_version(openai_module.version.VERSION) < (1, 6, 0) or not TIKTOKEN_AVAILABLE,
+    parse_version(openai_module.version.VERSION) < (1, 6, 0),
     reason="Streamed response context managers are only available v1.6.0+",
 )
 @pytest.mark.snapshot(token="tests.contrib.openai.test_openai.test_completion_stream")
 def test_completion_stream_context_manager(openai, openai_vcr, snapshot_tracer):
     with openai_vcr.use_cassette("completion_streamed.yaml"):
-        with mock.patch("ddtrace.contrib.internal.openai.utils.encoding_for_model", create=True) as mock_encoding:
-            mock_encoding.return_value.encode.side_effect = lambda x: [1, 2]
-            client = openai.OpenAI()
-            with client.completions.create(model="ada", prompt="Hello world", stream=True, n=None) as resp:
-                _ = [c for c in resp]
+        client = openai.OpenAI()
+        with client.completions.create(model="ada", prompt="Hello world", stream=True, n=None) as resp:
+            _ = [c for c in resp]
 
 
 @pytest.mark.skipif(
@@ -775,17 +787,15 @@ def test_completion_stream_context_manager(openai, openai_vcr, snapshot_tracer):
 def test_chat_completion_stream(openai, openai_vcr, snapshot_tracer):
     """Assert that streamed token chunk extraction logic works automatically."""
     with openai_vcr.use_cassette("chat_completion_streamed_tokens.yaml"):
-        with mock.patch("ddtrace.contrib.internal.openai.utils.encoding_for_model", create=True) as mock_encoding:
-            mock_encoding.return_value.encode.side_effect = lambda x: [1, 2, 3, 4, 5, 6, 7, 8]
-            client = openai.OpenAI()
-            resp = client.chat.completions.create(
-                model="gpt-3.5-turbo",
-                messages=[{"role": "user", "content": "Who won the world series in 2020?"}],
-                stream=True,
-                user="ddtrace-test",
-                n=None,
-            )
-            _ = [c for c in resp]
+        client = openai.OpenAI()
+        resp = client.chat.completions.create(
+            model="gpt-3.5-turbo",
+            messages=[{"role": "user", "content": "Who won the world series in 2020?"}],
+            stream=True,
+            user="ddtrace-test",
+            n=None,
+        )
+        _ = [c for c in resp]
 
 
 @pytest.mark.skipif(
@@ -794,19 +804,17 @@ def test_chat_completion_stream(openai, openai_vcr, snapshot_tracer):
 @pytest.mark.snapshot(token="tests.contrib.openai.test_openai.test_chat_completion_stream")
 async def test_chat_completion_async_stream(openai, openai_vcr, snapshot_tracer):
     with openai_vcr.use_cassette("chat_completion_streamed_tokens.yaml"):
-        with mock.patch("ddtrace.contrib.internal.openai.utils.encoding_for_model", create=True) as mock_encoding:
-            mock_encoding.return_value.encode.side_effect = lambda x: [1, 2, 3, 4, 5, 6, 7, 8]
-            client = openai.AsyncOpenAI()
-            resp = await client.chat.completions.create(
-                model="gpt-3.5-turbo",
-                messages=[
-                    {"role": "user", "content": "Who won the world series in 2020?"},
-                ],
-                stream=True,
-                n=None,
-                user="ddtrace-test",
-            )
-            _ = [c async for c in resp]
+        client = openai.AsyncOpenAI()
+        resp = await client.chat.completions.create(
+            model="gpt-3.5-turbo",
+            messages=[
+                {"role": "user", "content": "Who won the world series in 2020?"},
+            ],
+            stream=True,
+            n=None,
+            user="ddtrace-test",
+        )
+        _ = [c async for c in resp]
 
 
 @pytest.mark.skipif(
@@ -816,19 +824,17 @@ async def test_chat_completion_async_stream(openai, openai_vcr, snapshot_tracer)
 @pytest.mark.snapshot(token="tests.contrib.openai.test_openai.test_chat_completion_stream")
 async def test_chat_completion_async_stream_context_manager(openai, openai_vcr, snapshot_tracer):
     with openai_vcr.use_cassette("chat_completion_streamed_tokens.yaml"):
-        with mock.patch("ddtrace.contrib.internal.openai.utils.encoding_for_model", create=True) as mock_encoding:
-            mock_encoding.return_value.encode.side_effect = lambda x: [1, 2, 3, 4, 5, 6, 7, 8]
-            client = openai.AsyncOpenAI()
-            async with await client.chat.completions.create(
-                model="gpt-3.5-turbo",
-                messages=[
-                    {"role": "user", "content": "Who won the world series in 2020?"},
-                ],
-                stream=True,
-                user="ddtrace-test",
-                n=None,
-            ) as resp:
-                _ = [c async for c in resp]
+        client = openai.AsyncOpenAI()
+        async with await client.chat.completions.create(
+            model="gpt-3.5-turbo",
+            messages=[
+                {"role": "user", "content": "Who won the world series in 2020?"},
+            ],
+            stream=True,
+            user="ddtrace-test",
+            n=None,
+        ) as resp:
+            _ = [c async for c in resp]
 
 
 @pytest.mark.snapshot(
@@ -1350,3 +1356,113 @@ async def test_empty_streamed_response_resp_returns_async(openai, snapshot_trace
             stream=True,
         )
         assert resp is None
+
+
+@pytest.mark.skipif(
+    parse_version(openai_module.version.VERSION) < (1, 92), reason="Parse method only available in openai >= 1.92"
+)
+@pytest.mark.snapshot(token="tests.contrib.openai.test_openai_v1.test_chat_completion_parse")
+def test_chat_completion_parse(openai, openai_vcr, snapshot_tracer):
+    from typing import List
+
+    from pydantic import BaseModel
+
+    class Step(BaseModel):
+        explanation: str
+        output: str
+
+    class MathResponse(BaseModel):
+        steps: List[Step]
+        final_answer: str
+
+    with openai_vcr.use_cassette("chat_completion_parse.yaml"):
+        client = openai.OpenAI()
+        client.chat.completions.parse(
+            model="gpt-4o-2024-08-06",
+            messages=[
+                {"role": "system", "content": "You are a helpful math tutor."},
+                {"role": "user", "content": "solve 8x + 31 = 2"},
+            ],
+            response_format=MathResponse,
+        )
+
+
+@pytest.mark.skipif(
+    parse_version(openai_module.version.VERSION) < (1, 92), reason="Parse method only available in openai >= 1.92"
+)
+@pytest.mark.snapshot(token="tests.contrib.openai.test_openai_v1.test_chat_completion_parse")
+async def test_achat_completion_parse(openai, openai_vcr, snapshot_tracer):
+    from typing import List
+
+    from pydantic import BaseModel
+
+    class Step(BaseModel):
+        explanation: str
+        output: str
+
+    class MathResponse(BaseModel):
+        steps: List[Step]
+        final_answer: str
+
+    with openai_vcr.use_cassette("chat_completion_parse.yaml"):
+        client = openai.AsyncOpenAI()
+        await client.chat.completions.parse(
+            model="gpt-4o-2024-08-06",
+            messages=[
+                {"role": "system", "content": "You are a helpful math tutor."},
+                {"role": "user", "content": "solve 8x + 31 = 2"},
+            ],
+            response_format=MathResponse,
+        )
+
+
+@pytest.mark.skipif(
+    parse_version(openai_module.version.VERSION) < (1, 92), reason="Parse method only available in openai >= 1.92"
+)
+@pytest.mark.snapshot(token="tests.contrib.openai.test_openai_v1.test_response_parse")
+def test_response_parse(openai, openai_vcr, snapshot_tracer):
+    from typing import List
+
+    from pydantic import BaseModel
+
+    class Step(BaseModel):
+        explanation: str
+        output: str
+
+    class MathResponse(BaseModel):
+        steps: List[Step]
+        final_answer: str
+
+    with openai_vcr.use_cassette("response_parse.yaml"):
+        client = openai.OpenAI()
+        client.responses.parse(
+            model="gpt-4o-2024-08-06",
+            input="solve 8x + 31 = 2",
+            text_format=MathResponse,
+        )
+
+
+@pytest.mark.skipif(
+    parse_version(openai_module.version.VERSION) < (1, 92), reason="Parse method only available in openai >= 1.92"
+)
+@pytest.mark.snapshot(token="tests.contrib.openai.test_openai_v1.test_response_parse")
+async def test_aresponse_parse(openai, openai_vcr, snapshot_tracer):
+    from typing import List
+
+    from pydantic import BaseModel
+
+    class Step(BaseModel):
+        explanation: str
+        output: str
+
+    class MathResponse(BaseModel):
+        steps: List[Step]
+        final_answer: str
+
+    with openai_vcr.use_cassette("response_parse.yaml"):
+        client = openai.AsyncOpenAI()
+        await client.responses.parse(
+            model="gpt-4o-2024-08-06",
+            input="solve 8x + 31 = 2",
+            text_format=MathResponse,
+        )
