@@ -41,7 +41,6 @@ def expected_agent_metadata(instructions=None, system_prompt=None, model_setting
 def expected_run_agent_span_event(
     span,
     output,
-    token_metrics,
     input_value="Hello, world!",
     instructions=None,
     system_prompt=None,
@@ -54,7 +53,6 @@ def expected_run_agent_span_event(
         input_value=input_value,
         output_value=output,
         metadata=expected_agent_metadata(instructions, system_prompt, model_settings, tools),
-        token_metrics=token_metrics,
         tags={"ml_app": "<ml-app-name>", "service": "tests.contrib.pydantic_ai"},
     )
 
@@ -70,16 +68,6 @@ def expected_run_tool_span_event(span, input_value='{"x":2}', output="4"):
     )
 
 
-def get_usage(result):
-    usage = result.usage()
-    token_metrics = {
-        "input_tokens": getattr(usage, "request_tokens", 0),
-        "output_tokens": getattr(usage, "response_tokens", 0),
-        "total_tokens": getattr(usage, "total_tokens", 0),
-    }
-    return token_metrics
-
-
 def calculate_square_tool(x: int) -> int:
     """Calculates the square of a number"""
     return x * x
