@@ -66,6 +66,17 @@ class TestRayIntegration(TracerTestCase):
         results = ray.get(futures)
         assert results == [1, 2], f"Unexpected results: {results}"
 
+    @pytest.mark.snapshot(token="tests.contrib.ray.test_ray.test_task_error", ignores=RAY_SNAPSHOT_IGNORES)
+    def test_task_error(self):
+        @ray.remote
+        def add_one(x):
+            raise ValueError("foo")
+            return 0
+
+        futures = [add_one.remote(i) for i in range(2)]  # Reduced from 4 to 2 tasks
+        with pytest.raises(ValueError):
+            ray.get(futures)
+
     @pytest.mark.snapshot(token="tests.contrib.ray.test_ray.test_simple_actor", ignores=RAY_SNAPSHOT_IGNORES)
     def test_simple_actor(self):
         @ray.remote
@@ -93,6 +104,28 @@ class TestRayIntegration(TracerTestCase):
 
         assert current_value == 2, f"Unexpected result: {current_value}"
 
+    @pytest.mark.snapshot(token="tests.contrib.ray.test_ray.test_ignored_actored", ignores=RAY_SNAPSHOT_IGNORES)
+    def test_ignored_actors(self):
+        @ray.remote
+        class _InternalActor:
+            def one(self):
+                return 1
+
+        actor = _InternalActor.remote()
+        current_value = ray.get(actor.one.remote())
+        assert current_value == 1, f"Unexpected result: {current_value}"
+
+        class MockDeniedActor:
+            def get_value(self):
+                return 42
+
+        MockDeniedActor.__module__ = "ray.data._internal"
+        MockDeniedActor = ray.remote(MockDeniedActor)
+
+        denied_actor = MockDeniedActor.remote()
+        value = ray.get(denied_actor.get_value.remote())
+        assert value == 42, f"Unexpected result: {value}"
+
     @pytest.mark.snapshot(token="tests.contrib.ray.test_ray.test_nested_tasks", ignores=RAY_SNAPSHOT_IGNORES)
     def test_nested_tasks(self):
         @ray.remote
@@ -278,3 +311,22 @@ class TestRayIntegration(TracerTestCase):
             current_value = ray.get(counter_actor.increment.remote(1, y=2))
 
             assert current_value == 3, f"Unexpected result: {current_value}"
+
+
+class TestRayWithoutInit(TracerTestCase):
+    def tearDown(self):
+        if ray.is_initialized():
+            ray.shutdown()
+        super().tearDown()
+
+    @pytest.mark.snapshot(token="tests.contrib.ray.test_ray.test_task_without_init", ignores=RAY_SNAPSHOT_IGNORES)
+    def test_task_without_init(self):
+        """Test that tracing works when Ray auto-initializes without explicit ray.init()"""
+
+        @ray.remote
+        def add_one(x):
+            return x + 1
+
+        futures = [add_one.remote(i) for i in range(2)]
+        results = ray.get(futures)
+        assert results == [1, 2], f"Unexpected results: {results}"
