@@ -5,6 +5,7 @@ import redis
 from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.redis.patch import patch
 from ddtrace.contrib.internal.redis.patch import unpatch
+from ddtrace.internal.compat import PYTHON_VERSION_INFO
 from tests.contrib.config import REDISCLUSTER_CONFIG
 from tests.utils import DummyTracer
 from tests.utils import assert_is_measured
@@ -87,7 +88,8 @@ async def test_unicode(traced_redis_cluster):
 
 
 @pytest.mark.skipif(
-    redis.VERSION < (4, 3, 2), reason="redis.asyncio.cluster pipeline is not implemented in redis<4.3.2"
+    redis.VERSION < (4, 3, 2) or PYTHON_VERSION_INFO >= (3, 14),
+    reason="redis.asyncio.cluster pipeline is not implemented in redis<4.3.2. This test also fails under Python 3.14",
 )
 @pytest.mark.asyncio
 async def test_pipeline(traced_redis_cluster):
@@ -115,6 +117,7 @@ async def test_pipeline(traced_redis_cluster):
     assert span.get_metric("redis.pipeline_length") == 3
 
 
+@pytest.mark.skipif(PYTHON_VERSION_INFO >= (3, 14), reason="fails under Python 3.14")
 @pytest.mark.snapshot(wait_for_num_traces=1)
 @pytest.mark.asyncio
 async def test_pipeline_command_stack_count_matches_metric(redis_cluster):
@@ -128,6 +131,7 @@ async def test_pipeline_command_stack_count_matches_metric(redis_cluster):
         unpatch()
 
 
+@pytest.mark.skipif(PYTHON_VERSION_INFO >= (3, 14), reason="fails under Python 3.14")
 @pytest.mark.asyncio
 async def test_pipeline_command_stack_parity_when_visible(traced_redis_cluster):
     cluster, test_spans = traced_redis_cluster
