@@ -1,5 +1,4 @@
 import pytest
-import wrapt
 
 import ddtrace
 from ddtrace import config
@@ -9,6 +8,7 @@ from ddtrace.constants import ERROR_STACK
 from ddtrace.constants import ERROR_TYPE
 from ddtrace.contrib.internal.vertica.patch import patch
 from ddtrace.contrib.internal.vertica.patch import unpatch
+from ddtrace.internal.compat import is_wrapted
 from ddtrace.internal.schema import DEFAULT_SPAN_SERVICE_NAME
 from ddtrace.settings._config import _deepmerge
 from tests.contrib.config import VERTICA_CONFIG
@@ -63,8 +63,8 @@ class TestVerticaPatching(TracerTestCase):
         import vertica_python
 
         # use a patched method from each class as indicators
-        assert isinstance(vertica_python.Connection.cursor, wrapt.ObjectProxy)
-        assert isinstance(vertica_python.vertica.cursor.Cursor.execute, wrapt.ObjectProxy)
+        assert is_wrapted(vertica_python.Connection.cursor)
+        assert is_wrapted(vertica_python.vertica.cursor.Cursor.execute)
 
     def test_patch_after_import(self):
         """Patching _after_ the import will not work because we hook into
@@ -78,8 +78,8 @@ class TestVerticaPatching(TracerTestCase):
 
         import vertica_python
 
-        assert not isinstance(vertica_python.vertica.connection.Connection.cursor, wrapt.ObjectProxy)
-        assert not isinstance(vertica_python.vertica.cursor.Cursor.execute, wrapt.ObjectProxy)
+        assert not is_wrapted(vertica_python.vertica.connection.Connection.cursor)
+        assert not is_wrapted(vertica_python.vertica.cursor.Cursor.execute)
 
         patch()
 
@@ -91,33 +91,33 @@ class TestVerticaPatching(TracerTestCase):
         with mock_patch("vertica_python.connect", return_value=mock_conn):
             conn = vertica_python.connect()
             cursor = conn.cursor()
-            assert not isinstance(cursor, wrapt.ObjectProxy)
+            assert not is_wrapted(cursor)
 
     def test_idempotent_patch(self):
         patch()
         patch()
         import vertica_python
 
-        assert not isinstance(vertica_python.Connection.cursor.__wrapped__, wrapt.ObjectProxy)
-        assert not isinstance(vertica_python.vertica.cursor.Cursor.execute.__wrapped__, wrapt.ObjectProxy)
-        assert isinstance(vertica_python.Connection.cursor, wrapt.ObjectProxy)
-        assert isinstance(vertica_python.vertica.cursor.Cursor.execute, wrapt.ObjectProxy)
+        assert not is_wrapted(vertica_python.Connection.cursor.__wrapped__)
+        assert not is_wrapted(vertica_python.vertica.cursor.Cursor.execute.__wrapped__)
+        assert is_wrapted(vertica_python.Connection.cursor)
+        assert is_wrapted(vertica_python.vertica.cursor.Cursor.execute)
 
     def test_unpatch_before_import(self):
         patch()
         unpatch()
         import vertica_python
 
-        assert not isinstance(vertica_python.Connection.cursor, wrapt.ObjectProxy)
-        assert not isinstance(vertica_python.vertica.cursor.Cursor.execute, wrapt.ObjectProxy)
+        assert not is_wrapted(vertica_python.Connection.cursor)
+        assert not is_wrapted(vertica_python.vertica.cursor.Cursor.execute)
 
     def test_unpatch_after_import(self):
         patch()
         import vertica_python
 
         unpatch()
-        assert not isinstance(vertica_python.Connection.cursor, wrapt.ObjectProxy)
-        assert not isinstance(vertica_python.vertica.cursor.Cursor.execute, wrapt.ObjectProxy)
+        assert not is_wrapted(vertica_python.Connection.cursor)
+        assert not is_wrapted(vertica_python.vertica.cursor.Cursor.execute)
 
 
 @pytest.mark.usefixtures("test_tracer", "test_conn")
