@@ -275,6 +275,8 @@ def _expected_llmobs_eval_metric_event(
     boolean_value=None,
     tags=None,
     metadata=None,
+    assessment=None,
+    reasoning=None,
 ):
     eval_metric_event = {
         "join_on": {},
@@ -299,6 +301,10 @@ def _expected_llmobs_eval_metric_event(
         eval_metric_event["boolean_value"] = boolean_value
     if tags is not None:
         eval_metric_event["tags"] = tags
+    if assessment is not None:
+        eval_metric_event["assessment"] = assessment
+    if reasoning is not None:
+        eval_metric_event["reasoning"] = reasoning
     if timestamp_ms is not None:
         eval_metric_event["timestamp_ms"] = timestamp_ms
     else:
@@ -605,7 +611,7 @@ class DummyEvaluator:
 
     def run_and_submit_evaluation(self, span):
         self.llmobs_service.submit_evaluation(
-            span_context=span,
+            span=span,
             label=self.LABEL,
             value=1.0,
             metric_type="score",
