@@ -90,7 +90,7 @@ def test_otel_api_version_not_supported(ddtrace_run_python_code_in_subprocess):
     """Test error when OpenTelemetry API version is too old."""
     env = os.environ.copy()
     env["DD_LOGS_OTEL_ENABLED"] = "true"
-    stdout, stderr, status, _ = ddtrace_run_python_code_in_subprocess(code="", env=env)
+    stdout, stderr, status, _ = ddtrace_run_python_code_in_subprocess(code="import opentelemetry", env=env)
     assert status == 0, (stdout, stderr)
     assert (
         "OpenTelemetry API requires version 1.15.0 or higher to enable logs collection. "
@@ -107,7 +107,7 @@ def test_otel_sdk_not_installed(ddtrace_run_python_code_in_subprocess):
     """Test error when OpenTelemetry SDK is not installed."""
     env = os.environ.copy()
     env["DD_LOGS_OTEL_ENABLED"] = "true"
-    stdout, stderr, status, _ = ddtrace_run_python_code_in_subprocess(code="", env=env)
+    stdout, stderr, status, _ = ddtrace_run_python_code_in_subprocess(code="import opentelemetry", env=env)
     assert status == 0, (stdout, stderr)
 
     assert (
@@ -200,7 +200,6 @@ def test_otel_logs_exporter_auto_configured_http():
 
     from opentelemetry._logs import get_logger_provider
 
-    from ddtrace.internal.opentelemetry.logs import HTTP_LOGS_ENDPOINT
     from tests.opentelemetry.test_logs import decode_logs_request
     from tests.opentelemetry.test_logs import extract_log_correlation_attributes
 
@@ -217,7 +216,7 @@ def test_otel_logs_exporter_auto_configured_http():
         request_body = None
         for call in mock_request.call_args_list:
             method, url = call[0][:2]
-            if method == "POST" and HTTP_LOGS_ENDPOINT in url:
+            if method == "POST" and "/v1/logs" in url:
                 request_body = call[1].get("data", None)
                 break
         assert request_body is not None, (
@@ -505,3 +504,62 @@ def test_otel_trace_log_correlation():
     assert (
         int(attributes["span_id"], 16) == span_context.span_id
     ), f"Expected span_id_hex to be set to {attributes['span_id']} but found: {span_context.span_id}"
+
+
+@pytest.mark.skipif(
+    EXPORTER_VERSION < MINIMUM_SUPPORTED_VERSION,
+    reason=f"OpenTelemetry exporter version {MINIMUM_SUPPORTED_VERSION} is required to export logs",
+)
+@pytest.mark.snapshot()
+@pytest.mark.subprocess(ddtrace_run=True, env={"DD_LOGS_OTEL_ENABLED": "true"})
+def test_otel_logs_does_not_generate_client_grpc_spans():
+    """
+    Test that OpenTelemetry grpc logs exporter does not generate client grpc spans.
+    """
+    from logging import getLogger
+
+    from opentelemetry._logs import get_logger_provider
+
+    from tests.opentelemetry.test_logs import create_mock_grpc_server
+
+    logger = getLogger()
+    mock_service, server = create_mock_grpc_server()
+
+    try:
+        server.start()
+        logger.error("test_otel_logs_grpc")
+        get_logger_provider().force_flush()
+    finally:
+        server.stop(0)
+
+    assert mock_service.received_requests, "Expected gRPC log export requests but received none"
+
+
+@pytest.mark.skipif(
+    EXPORTER_VERSION < MINIMUM_SUPPORTED_VERSION,
+    reason=f"OpenTelemetry exporter version {MINIMUM_SUPPORTED_VERSION} is required to export logs",
+)
+@pytest.mark.snapshot()
+@pytest.mark.subprocess(
+    ddtrace_run=True, env={"DD_LOGS_OTEL_ENABLED": "true", "OTEL_EXPORTER_OTLP_PROTOCOL": "http/protobuf"}
+)
+def test_otel_logs_does_not_generate_client_http_spans():
+    """Test that OpenTelemetry http logs exporter does not generate client spans."""
+    from logging import getLogger
+    from unittest.mock import Mock
+    from unittest.mock import patch
+
+    from opentelemetry._logs import get_logger_provider
+
+    logger = getLogger()
+    with patch("requests.sessions.Session.request") as mock_request:
+        mock_request.return_value = Mock(status_code=200)
+
+        logger.error("test_otel_logs_http")
+        get_logger_provider().force_flush()
+
+        log_request_found = any(
+            len(call[0]) >= 2 and call[0][0] == "POST" and "/v1/logs" in call[0][1]
+            for call in mock_request.call_args_list
+        )
+        assert log_request_found, f"Expected HTTP log export request but found none: {mock_request.call_args_list}"
