@@ -145,24 +145,3 @@ def test_profiler_serverless(monkeypatch):
     p = profiler.Profiler()
     assert isinstance(p._scheduler, scheduler.ServerlessScheduler)
     assert p.tags["functionname"] == "foobar"
-
-
-@pytest.mark.subprocess()
-def test_profiler_ddtrace_deprecation():
-    """
-    ddtrace interfaces loaded by the profiler can be marked deprecated, and we should update
-    them when this happens.  As reported by https://github.com/DataDog/dd-trace-py/issues/8881
-    """
-    import warnings
-
-    with warnings.catch_warnings():
-        warnings.simplefilter("error", DeprecationWarning)
-        from ddtrace.profiling import _threading  # noqa:F401
-        from ddtrace.profiling import event  # noqa:F401
-        from ddtrace.profiling import profiler  # noqa:F401
-        from ddtrace.profiling import scheduler  # noqa:F401
-        from ddtrace.profiling.collector import _lock  # noqa:F401
-        from ddtrace.profiling.collector import _task  # noqa:F401
-        from ddtrace.profiling.collector import _traceback  # noqa:F401
-        from ddtrace.profiling.collector import memalloc  # noqa:F401
-        from ddtrace.profiling.collector import stack  # noqa:F401
