@@ -16,7 +16,7 @@ def index():
 def starting_app_view():
     # We must call app-started before telemetry events can be sent to the agent.
     # This endpoint mocks the behavior of the agent writer.
-    telemetry_writer._app_started()
+    telemetry_writer._report_app_started()
     return "OK", 200
 
 
