@@ -315,7 +315,8 @@ def test_aggregator_partial_flush_0_spans():
     assert parent.get_metric("_dd.py.partial_flush") == 1
     child.finish()
     assert writer.pop() == [child]
-    assert child.get_metric("_dd.py.partial_flush") == 1
+    # Not a partial flush since the trace size at this point is 1 and we finished the last span
+    assert child.get_metric("_dd.py.partial_flush") is None
 
 
 def test_aggregator_partial_flush_2_spans():
