@@ -102,7 +102,7 @@ class AgentWriterTests(BaseTestCase):
                 for j in range(50):
                     key = "opqr012|~" + str(i) + str(j)
                     val = "stuv345!@#" + str(i) + str(j)
-                    span.set_tag_str(key, val)
+                    span._set_tag_str(key, val)
                 massive_trace.append(span)
 
             writer.write(massive_trace)
@@ -495,7 +495,7 @@ class NativeWriterTests(AgentWriterTests):
                 for j in range(50):
                     key = "opqr012|~" + str(i) + str(j)
                     val = "stuv345!@#" + str(i) + str(j)
-                    span.set_tag_str(key, val)
+                    span._set_tag_str(key, val)
                 massive_trace.append(span)
 
             writer.write(massive_trace)
