@@ -9,6 +9,7 @@ from azure.storage.blob import BlobServiceClient
 from azure.storage.queue import QueueServiceClient
 from cassandra.cluster import Cluster
 from cassandra.cluster import NoHostAvailable
+from contrib.config import AZURE_EVENT_HUBS_EMULATOR_CONFIG
 from contrib.config import AZURE_SERVICE_BUS_EMULATOR_CONFIG
 from contrib.config import AZURE_SQL_EDGE_CONFIG
 from contrib.config import AZURITE_CONFIG
@@ -142,6 +143,16 @@ def check_moto(url):
     requests.get(url).raise_for_status()
 
 
+@try_until_timeout(
+    Exception,
+    tries=120,
+    timeout=1,
+    args={"url": "http://{host}:{port}/health".format(**AZURE_EVENT_HUBS_EMULATOR_CONFIG)},
+)
+def check_azureeventhubsemulator(url):
+    requests.get(url).raise_for_status()
+
+
 @try_until_timeout(
     Exception,
     tries=120,
@@ -184,7 +195,7 @@ if __name__ == "__main__":
         "cassandra": check_cassandra,
         "ddagent": check_agent,
         "elasticsearch": check_elasticsearch,
-        "httpbin_local": check_httpbin,
+        "httpbin": check_httpbin,
         "moto": check_moto,
         "mysql": check_mysql,
         "opensearch": check_opensearch,
@@ -192,6 +203,7 @@ if __name__ == "__main__":
         "rabbitmq": check_rabbitmq,
         "testagent": check_agent,
         "vertica": check_vertica,
+        "azureeventhubsemulator": check_azureeventhubsemulator,
         "azureservicebusemulator": check_azureservicebusemulator,
         "azuresqledge": check_azuresqledge,
         "azurite": check_azurite,
